_positive = set(
    [
        "αβάς",
        "ικανότητα",
        "NO TRANSLATION",
        "απόλυτος",
        "απαλλαγή",
        "απορροφηθεί",
        "άφθονος",
        "ακαδημαϊκός",
        "ακαδημία",
        "δεκτός",
        "αποδοχή",
        "προσιτός",
        "χειροτονία ιππότου",
        "κατάλυμα",
        "συνοδεία",
        "ολοκληρώσει",
        "τέλειος",
        "εκπλήρωση",
        "συμφωνία",
        "Ευθύνη",
        "υπεύθυνος",
        "διαπιστευμένος",
        "NO TRANSLATION",
        "ακριβής",
        "άσσος",
        "φέρνω σε πέρας",
        "κατόρθωμα",
        "αναγνώριση",
        "αποκτώ",
        "απόκτηση",
        "ακροβάτης",
        "δράση",
        "πραγματικός",
        "οξύτητα",
        "οξύνοια",
        "προσαρμόζω",
        "προσαρμόσιμος",
        "διευθύνσεις",
        "έμπειρος",
        "NO TRANSLATION",
        "παρεπόμενο",
        "θαυμαστός",
        "ναύαρχος",
        "θαυμασμός",
        "θαυμάζω",
        "θαυμαστής",
        "αποδεκτός",
        "λατρευτός",
        "λατρεία",
        "λατρεύω",
        "προκαταβολή",
        "προχωρημένος",
        "προαγωγή",
        "πλεονέκτημα",
        "επωφελής",
        "έλευση",
        "περιπέτεια",
        "παράτολμος",
        "ορθός",
        "συμβουλεύω",
        "σύμβουλος",
        "υπεράσπιση",
        "αισθητικός",
        "αισθητική",
        "καταδεκτικός",
        "στοργή",
        "συνδεδεμένη",
        "επιβεβαιώνουμε",
        "επιβεβαίωση",
        "καταφατικός",
        "καταφατικά",
        "αφθονία",
        "άφθονος",
        "ΟΙΚΟΝΟΜΙΚΗ δυνατοτητα",
        "NO TRANSLATION",
        "ευκίνητος",
        "ευκινησία",
        "συμφωνώ",
        "ευχάριστος",
        "σύμφωνος",
        "συμφωνώ",
        "συμφωνία",
        "γεωργία",
        "εμπρός",
        "βοήθεια",
        "βοηθώντας",
        "αλαβάστρο",
        "ετοιμότητα",
        "NO TRANSLATION",
        "ζωντανός",
        "ανακουφίζω",
        "υποταγή",
        "γοργά",
        "ανακουφίζω",
        "ανακούφιση",
        "σύμμαχος",
        "επιτρεπόμενος",
        "δελεάζω",
        "δελεαστικός",
        "σύμμαχος",
        "παντοδύναμος",
        "aloha",
        "καταπληκτικά",
        "πρεσβευτής",
        "φιλοδοξία",
        "βελτιώνω",
        "Αμήν",
        "υπαγόμενος",
        "τροποποιώ",
        "αποζημίωση",
        "φιλοφροσύνη",
        "ευγενικός",
        "φιλικός",
        "αμνηστία",
        "NO TRANSLATION",
        "διασκεδάζω",
        "διασκέδασε",
        "διασκέδαση",
        "διασκεδαστικός",
        "αναλυτής",
        "άγκυρα",
        "αγκυροβόλιο",
        "άγγελος",
        "αγγελικός",
        "έμψυχος",
        "κινούμενα",
        "αντιβιοτικά",
        "αντίδοτο",
        "αντιμυκητιασικά",
        "αντίκα",
        "αντισηπτικό",
        "ψυχραιμία",
        "απολογητικός",
        "Απολογούμαι",
        "απολογία",
        "απόστολος",
        "χειροκροτήματα",
        "εκτίμηση",
        "επιδοκιμασία",
        "έγκριση",
        "εγκρίνω",
        "έγκριση",
        "κατάλληλος",
        "ικανότητα",
        "αρχαιολογία",
        "διακαής",
        "ζέση",
        "αριστοκρατία",
        "αριστοκρατικός",
        "πανοπλία",
        "άρωμα",
        "εξεγείρω",
        "παράταξη",
        "τέχνη",
        "διατυπώσει",
        "άρθρωσις",
        "τεχνίτης",
        "NO TRANSLATION",
        "καλλιτεχνικός",
        "υπεροχή",
        "ανάβαση",
        "φιλοδοξία",
        "φιλοδοξώ",
        "επιδιώκοντας",
        "συνέλευση",
        "συγκατάθεση",
        "ισχυριζόμενος",
        "περιουσιακά στοιχεία",
        "βοηθώ",
        "βοήθεια",
        "σύντροφος",
        "καταπραΰνω",
        "ασφάλεια",
        "βέβαιος",
        "NO TRANSLATION",
        "κατάπληξη",
        "αστρολόγος",
        "αστροναύτης",
        "αστρονόμος",
        "οξύνους",
        "αθλητής",
        "αθλητικός",
        "άτομο",
        "εξιλεώ",
        "εξιλέωση",
        "συνημμένο",
        "εφικτός",
        "επίτευξη",
        "παραστάτης",
        "προσοχή",
        "προσεκτικός",
        "πιστοποιώ",
        "δικηγόρος",
        "αξιοθεατο",
        "ελκυστικότητα",
        "αυξάνω",
        "Αύγουστος",
        "θεία",
        "αύρα",
        "ευοίωνος",
        "αυθεντικός",
        "αυθεντικότητα",
        "συγγραφέας",
        "επίσημος",
        "εξουσία",
        "εξουσιοδότηση",
        "εξουσιοδοτημένο",
        "avatar",
        "βραβείο",
        "ay",
        "πάντοτε",
        "μωρό",
        "πτυχιούχος πανεπιστημίου",
        "σπονδυλική στήλη",
        "ισορροπία",
        "ισορροπημένη",
        "μπαλάντα",
        "μπαλέτο",
        "ψηφοφορία",
        "βάλσαμο",
        "συμπόσιο",
        "βάπτισμα",
        "βαπτιστικός",
        "βάρδος",
        "παζάρι",
        "μπάσκετ",
        "προπύργιο",
        "λούτρο",
        "δέσμη",
        "ακτινοβολία",
        "καλλωπισμός",
        "πανεμορφη",
        "καλλωπίζω",
        "ομορφιά",
        "υπόβαθρο",
        "μπύρα",
        "αρμόζων",
        "φέρομαι φιλικά σε",
        "πιστεύοντας",
        "ευεργέτης",
        "ευεργετικός",
        "όφελος",
        "καλοσύνη",
        "αγαθός",
        "κουκέτα",
        "μνηστή",
        "βελτίωση",
        "ποτό",
        "βιβλικός",
        "δίγλωσσος",
        "γέννηση",
        "γενέθλια",
        "άμεμπτος",
        "ευλογώ",
        "ευλογημένος",
        "ευλογία",
        "ευλογίες",
        "ευδαιμονία",
        "ευτυχισμένος",
        "αναίμακτος",
        "ανθίζω",
        "άνθος",
        "σωματοφύλακας",
        "τολμηρός",
        "τόλμη",
        "μαξιλάρα",
        "εύρημα",
        "NO TRANSLATION",
        "δώρο",
        "σχολαστικός",
        "βιβλιοπωλείο",
        "δώρο",
        "γενναιόδωρος",
        "γενναιοδωρία",
        "μπουκέτο",
        "μυαλά",
        "γενναιότητα",
        "ΠΡΩΙΝΟ ΓΕΥΜΑ",
        "γάμος",
        "νυφη",
        "γαμπρός",
        "παράνυμφος",
        "λαμπρύνω",
        "λάμψη",
        "λαμπρός",
        "μπροκάρ",
        "αδελφός",
        "αδελφότητα",
        "αδελφικός",
        "φίλε",
        "χτίζω",
        "Κτίριο",
        "σκύλος μπουλντώκ",
        "αλεξίσφαιρος",
        "σημαδούρα",
        "φίλημα",
        "μπάτλερ",
        "κολακευτικός",
        "ζωηρός",
        "βόμβος",
        "ταξί",
        "υπουργικό συμβούλιο",
        "καφενείο",
        "αριθμομηχανή",
        "μοσχάρι",
        "ηρεμία",
        "καναρίνι",
        "ειλικρινής",
        "υποψήφιος",
        "γκλασέ",
        "καπιταλιστής",
        "Καπετάνιος",
        "σαγηνεύω",
        "γοητευτικό",
        "καριέρα",
        "προσεκτικός",
        "προσεκτικά",
        "χάδι, χαϊδεύω",
        "επιστάτης",
        "κάλαντα",
        "αλληλουχία",
        "μετρητά",
        "κατηγορηματικός",
        "προμηθεύω",
        "καθαρτικό",
        "καθεδρικός ναός",
        "προσεκτικός",
        "με προσοχή",
        "διάσημος",
        "γιορτάζοντας",
        "εορτασμός",
        "ουράνιος",
        "κέντρο",
        "εκατόνταρχος",
        "εγκεφαλικός",
        "τελετή",
        "βεβαιότητα",
        "Πρόεδρος",
        "πρόεδρος",
        "πρωταθλητής",
        "άσμα",
        "Φορτιστής",
        "φιλάνθρωπος",
        "φιλανθρωπία",
        "γοητεία",
        "γοητευτικός",
        "αγνότητα",
        "φλυαρία",
        "ΛΙΣΤΑ ΕΛΕΓΧΟΥ",
        "κέφι",
        "χαρούμενος",
        "φαιδρότητα",
        "επευφημίες",
        "NO TRANSLATION",
        "χημικός",
        "διατηρώ",
        "κεράσι",
        "οπλαρχηγός",
        "παιδί",
        "Παιδική ηλικία",
        "τερέτισμα",
        "σμίλη",
        "ιπποτισμός",
        "σοκολάτα",
        "επιλογή",
        "χορωδία",
        "χορικός",
        "Χορωδία",
        "εκλεκτός",
        "στρειδόσουπα",
        "χρονικό",
        "συγκρατημένο γέλιο",
        "Εκκλησία",
        "μηλίτης",
        "περιτομή",
        "πολίτης",
        "εμφύλιος",
        "ευγένεια",
        "πολιτισμός",
        "πολιτισμένος",
        "μάντης",
        "χειροκρότημα",
        "διευκρινίζω",
        "κλασσικός",
        "κλασσικός",
        "κλασικά",
        "ταξινόμηση",
        "ΚΑΘΑΡΗ",
        "καθάρισμα",
        "καθαριότητα",
        "καθαρά",
        "καθαρίζω",
        "καθαρισμό",
        "εκτελωνισμός",
        "καθαρότητα",
        "κληρικός",
        "έξυπνος",
        "εξυπνάδα",
        "κορύφωση",
        "εγγύτητα",
        "κλείσιμο",
        "NO TRANSLATION",
        "κλόουν",
        "συνασπισμός",
        "ακτή",
        "συνυπάρχω",
        "πειστικός",
        "γνωστική",
        "συνοχή",
        "συναφής",
        "συνεκτικός",
        "συλλογικά",
        "συνταγματάρχης",
        "κολοσσιαίος",
        "άνεση",
        "διοικητής",
        "διοικών",
        "εορτάζω την μνήμη",
        "εορτασμός",
        "αναμνηστικός",
        "συνιστώ",
        "αξιέπαινος",
        "σχολιαστής",
        "δεσμεύεται",
        "ανώτερος αξιωματικός του ναυτικού",
        "κοινοπολιτεία",
        "ΕΠΙΚΟΙΝΩΝΩ",
        "ομιλητικός",
        "κοινωνία",
        "κοινότητα",
        "μετατροπή",
        "ανταλάσσω",
        "σύντροφος",
        "συμπόνια",
        "συμπονετικός",
        "συμβατότητα",
        "σύμφωνος",
        "συναρπαστικό",
        "αποζημιώνω",
        "αποζημιωτικός",
        "επάρκεια",
        "ικανότητας",
        "ικανός",
        "εφησυχασμό",
        "συμπλήρωμα",
        "συμπληρωματικός",
        "εντελώς",
        "πληρότητα",
        "ολοκληρώνοντας",
        "ολοκλήρωση",
        "συμμόρφωση",
        "υποχωρητικός",
        "NO TRANSLATION",
        "απαρτίζεται",
        "συνθέτης",
        "ψυχραιμία",
        "κατανοώ",
        "περιεκτικός",
        "σύντροφος",
        "ομόκεντρος",
        "συμβιβασμός",
        "Καταλήγοντας",
        "ομόνοια",
        "συμφωνία",
        "συλλυπητήρια",
        "συγχωρώ",
        "συμβάλλων",
        "αγώγιμο",
        "συνασπίζομαι",
        "αυτοπεποίθηση",
        "βέβαιος",
        "επιβεβαιωμένος",
        "συμμόρφωση",
        "συμπαθής",
        "συγχαρητήριος",
        "εκκλησίασμα",
        "μαθηματική αναλογία",
        "γνώστης",
        "συνείδηση",
        "ευσυνείδητος",
        "συνείδηση",
        "καθαγίαση",
        "διατήρηση",
        "συντηρώ",
        "σημαντικός",
        "διακριτικός",
        "συνοχή",
        "κονσόλα",
        "σύμφωνο",
        "σταθερότητα",
        "συνεχής",
        "συνταγματικός",
        "κατασκευάσει",
        "τέλειος",
        "Επικοινωνία",
        "ενατένιση",
        "περιεχόμενο",
        "να συνεχίσει",
        "περίγραμμα",
        "συμβάλλει",
        "συνεισφέρων",
        "ευκολία",
        "βολικός",
        "γυναικεία μονή",
        "σύμβαση",
        "εντριβής",
        "ομιλητικός",
        "μετατρέπω",
        "πείθω",
        "δροσερός",
        "ψυχρότητα",
        "συνεργάζονται",
        "συνεργασία",
        "συνεργασία",
        "συνεργατική",
        "πυρήνας",
        "στέψη",
        "εταιρεία",
        "σωματικός",
        "διορθωτικός",
        "αλληλογραφία",
        "ενισχύω",
        "κοσμοπολίτικος",
        "ζεστός",
        "συμβούλιο",
        "ο ΣΥΝΗΓΟΡΟΣ",
        "σύμβουλος",
        "μετρώ",
        "κόμισσα",
        "θάρρος",
        "θαρραλέος",
        "ευγενής",
        "ευγένεια",
        "ερωτοτροπία",
        "λιμανάκι",
        "σύμφωνο",
        "κούνια",
        "σκάφος",
        "τεχνίτης",
        "κρέμα",
        "δημιουργώ",
        "δημιουργικός",
        "πίστη",
        "πιστοποιητικό",
        "αξιοπιστία",
        "αξιόπιστος",
        "πίστωση",
        "NO TRANSLATION",
        "πιστώθηκε",
        "αυξάνων τόνος",
        "κριτική",
        "στέμμα",
        "κρίσιμος",
        "κρύσταλλο",
        "αγκαλιάζω",
        "μαγειρικός",
        "αποκορύφωμα",
        "καλλιεργώ",
        "καλλιεργημένος",
        "καλλιέργεια",
        "Πολιτισμός",
        "θεραπεύσιμος",
        "περιέργεια",
        "μπούκλα",
        "μαξιλάρι",
        "πελάτης",
        "χαριτωμένος",
        "κόφτες",
        "κυρά",
        "χορός",
        "τόλμη",
        "πολυαγαπημένος",
        "τολμηρός",
        "κόρη",
        "αυγή",
        "συμφωνία",
        "αγαπητός",
        "δημόσια συζήτηση",
        "ευπρέπεια",
        "κόσμιος",
        "δηλωτικός",
        "αφιέρωση",
        "υπερασπίζω",
        "υπερασπιστεί",
        "υπερασπιστής",
        "υπεράσπιση",
        "άμυνα",
        "υποχώρηση",
        "οριστικός",
        "βαθμός",
        "απολαυστικός",
        "αντιπρόσωπος",
        "σκόπιμος",
        "νόστιμο",
        "απόλαυση",
        "ευχαριστημένος",
        "γοητευτικός",
        "απελευθέρωση",
        "διανομή",
        "Δημοκρατία",
        "αποδείξιμος",
        "εκδηλωτικός",
        "βάθος",
        "περιγραφικός",
        "αξίζω",
        "άξιζε",
        "σχεδιαστής",
        "επιθυμητός",
        "επιθυμώντας",
        "επιθυμών",
        "προορισμός",
        "ανιχνεύουν",
        "ανίχνευση",
        "προσδιορισμός",
        "προσδιορίζεται",
        "αναπτύσσω",
        "ευλαβής",
        "ευσεβής",
        "επιδεξιότητα",
        "διαμάντι",
        "ημερολόγιο",
        "λεξικό",
        "διδακτικός",
        "διαίτης",
        "αξιοπρεπής",
        "αξιοπρέπεια",
        "επιμέλεια",
        "βραδινό",
        "διπλωματία",
        "διπλωματικός",
        "διευθυντής",
        "ανακάλυψη",
        "NO TRANSLATION",
        "διακριτικότητα",
        "διακριτική ευχέρεια",
        "συζήτηση",
        "απολύμανση",
        "διατεθειμένος",
        "διασπείρω",
        "απόσταξη",
        "διάκριση",
        "ποιηματάκι",
        "διαφοροποιημένη",
        "εκτροπή",
        "θειότητα",
        "γιατρός",
        "πράττων",
        "πεισματάρης",
        "δελφίνι",
        "υφηγητής",
        "δωρεά",
        "αναμφίβολα",
        "περιστέρι",
        "χνουδάτος",
        "ντουέτο",
        "δούκας",
        "αντοχή",
        "διαρκής",
        "υπάκουος",
        "πρόθυμος",
        "προθυμία",
        "κόμης",
        "κερδίζω",
        "σοβαρός",
        "ένθερμα",
        "σοβαρότητα",
        "ευκολία",
        "τρίποδας ζωγράφου",
        "NO TRANSLATION",
        "τρώω",
        "έκσταση",
        "εκστατικός",
        "διαπαιδαγώγηση",
        "εκπαιδεύσει",
        "μορφωμένος",
        "εκπαιδευτικός",
        "αποτελεσματικός",
        "αποτελεσματικότητα",
        "αποδοτικότητα",
        "αποτελεσματικός",
        "προσπάθεια",
        "εκσπερμάτωση",
        "επεξεργασία",
        "με ενθουσιασμό",
        "μεγαλύτερος",
        "οι πρεσβύτεροι",
        "εκλεκτός",
        "ηλεκτρικός",
        "ηλεκτρική ενέργεια",
        "κομψότητα",
        "κομψός",
        "ανύψωση",
        "επιλέξιμες",
        "αφρόκρεμα",
        "ευγλωττία",
        "εύγλωττος",
        "διευκρινίζω",
        "χειραφέτηση",
        "εναγκαλισμός",
        "επίτιμος",
        "υπεροχή",
        "διαπρεπής",
        "εκλεκτά",
        "NO TRANSLATION",
        "ενσυναίσθηση",
        "εξουσιοδοτώ",
        "μιμούμαι",
        "επιτρέπω",
        "ενεργοποίηση",
        "θέλγω",
        "μαγεμένο",
        "μαγευτικός",
        "NO TRANSLATION",
        "ενθαρρύνω",
        "ενθάρρυνση",
        "εγκυκλοπαιδεία",
        "προσπαθώ",
        "προικίζω",
        "προικισμένος",
        "προικοδότηση",
        "αντοχή",
        "υποφέρω",
        "ενεργητικός",
        "αρραβωνιασμένος",
        "ελκυστικός",
        "ενισχύω",
        "απολαμβάνω",
        "απολαμβάνοντας",
        "διαφωτίζω",
        "διαφώτιση",
        "ζωντανεύω",
        "εμπλουτίζω",
        "σύνολο",
        "σημαία",
        "επιχειρηματικός",
        "διασκεδάζω",
        "διασκέδαση",
        "διασκεδαστικο",
        "ψυχαγωγία",
        "ενθουσιασμός",
        "θιασώτης",
        "NO TRANSLATION",
        "ephemeris",
        "έπος",
        "επιτομή",
        "ισότητα",
        "εξίσου",
        "ισορροπία",
        "μετοχικό κεφάλαιο",
        "θέλημα",
        "πολυμαθής",
        "πνεύμα",
        "ουσιώδης",
        "καθιερωμένος",
        "εκτίμηση",
        "αισθητική",
        "ηθικά",
        "ηθική",
        "αειθαλής",
        "αιώνιος",
        "εμφανές",
        "εξέλιξη",
        "εκθειάζω",
        "εξύψωση",
        "εξόριστος",
        "υπερβαίνω",
        "προέχω",
        "υπεροχή",
        "έξοχος",
        "ανταλλαγή",
        "ευερέθιστος",
        "διέγερση",
        "διεγείρω",
        "ενθουσιασμένος",
        "ενθουσιασμός",
        "συναρπαστικός",
        "παραδειγματικός",
        "απαλλαγή",
        "χαρά",
        "προτρέπω",
        "προτροπή",
        "ύπαρξη",
        "εξωτικός",
        "αναμένω",
        "προσδοκία",
        "τέχνασμα",
        "εκστρατεία",
        "έμπειρος",
        "ειδικός",
        "εξειδίκευση",
        "εξηγώ",
        "πανέμορφος",
        "εξαίσια",
        "επεκτείνω",
        "εκτενής",
        "επιπλέον",
        "έκτακτος",
        "απαλλάσσω",
        "μεγάλη αφθονία",
        "διευκολύνω",
        "γεγονότα",
        "σχολή",
        "NO TRANSLATION",
        "έκθεση",
        "αρκετά",
        "πίστη",
        "πιστός",
        "φήμη",
        "οικείος",
        "εξοικείωση",
        "περίφημος",
        "φημισμένα",
        "φαντασία",
        "σαλπίσματα",
        "γοητευτικός",
        "γοητεία",
        "μόδας",
        "άψογος",
        "ευνοϊκός",
        "αγαπημένη",
        "προσωποληψία",
        "ατρόμητος",
        "κατόρθωμα",
        "χαρακτηριστικό",
        "ευδαιμονία",
        "σύντροφος",
        "υποτροφία",
        "θηλυκός",
        "εύφορος",
        "θέρμη",
        "Φεστιβάλ",
        "εορταστικός",
        "NO TRANSLATION",
        "πιστότητα",
        "γιορτή",
        "τελικά",
        "στολίδια",
        "φινέτσα",
        "πυρκαγιά",
        "άφλεκτος",
        "σταθερότητα",
        "NO TRANSLATION",
        "προσαρμογή",
        "αναπόσπαστο εξάρτημα",
        "κολακευτικός",
        "στόλος",
        "ευκαμψία",
        "άνθινος",
        "ροή",
        "ανθηρός",
        "ξεπλύνετε",
        "πέταγμα",
        "Συγκεντρώνω",
        "αγάπη",
        "τροφή",
        "ποδόσφαιρο",
        "ανοχή",
        "εμπρός",
        "προπάτορες",
        "προηγούμενος",
        "επιστάτης",
        "πρόδρομος",
        "προβλέπω",
        "προβλέπεται",
        "πρόβλεψη",
        "σιδηρουργείο",
        "συγχωρώ",
        "συγχωρείται",
        "επιεικής",
        "διαμορφωτικός",
        "τύπος",
        "NO TRANSLATION",
        "προσεχής",
        "οχυρώνω",
        "σθένος",
        "φρούριο",
        "τυχερός",
        "τύχη",
        "προς τα εμπρός",
        "βρέθηκαν",
        "θεμέλιο",
        "ευώδης",
        "ειλικρινής",
        "παρρησία",
        "αδελφικός",
        "ελευθερία",
        "ελευθερώς",
        "φίλος",
        "φιλικότητα",
        "φιλικός",
        "φιλία",
        "ζωηρός",
        "ευθυμία",
        "ολιγαρκής",
        "καρποφόρος",
        "εκπληρώ",
        "εκπλήρωση",
        "γεμάτος",
        "πλήρως",
        "διασκέδαση",
        "θεμελιώδης",
        "ασφάλεια ηλεκτρική",
        "σύντηξη",
        "κέρδος",
        "κερδίζοντας",
        "γενναίος",
        "γενναιότητα",
        "εν αφθονία",
        "κήπος",
        "λυχνίτης",
        "φρουρά",
        "εφημερίδα",
        "μηχανισμός",
        "κόσμημα",
        "γενικός",
        "γενναιοδωρία",
        "γενναιόδωρος",
        "καλόκαρδος",
        "ιδιοφυία",
        "ευγενικός",
        "κύριος",
        "ευγένεια",
        "οι ευγενείς",
        "γνήσιος",
        "γεράνι",
        "δώρο",
        "προικισμένος",
        "πελώριος",
        "νευρικό γέλιο",
        "δοκός",
        "δίνοντας",
        "χαρούμενος",
        "χαρά",
        "χαρά",
        "γλιστρώ",
        "φέγγω",
        "λαμπερό",
        "δοξολογία",
        "δοξάζω",
        "δόξα",
        "στιλπνότητα",
        "λάμψη",
        "λαμπερός",
        "θεός",
        "θεοσεβής",
        "απροσδόκητο καλό",
        "χρυσός",
        "Καλός",
        "ωραία",
        "καλοσύνη",
        "εμπορεύματα",
        "φήμη και πελατεία",
        "υπέροχος",
        "Ευαγγέλιο",
        "κυβερνώ",
        "χάρη",
        "χαριτωμένος",
        "ελεήμων",
        "ευγενικά",
        "αποφοίτηση",
        "εγγονια",
        "μεγαλείο",
        "γιαγιά",
        "χορήγηση",
        "χορηγείται",
        "ευγνώμων",
        "ικανοποιώ",
        "ευγνωμοσύνη",
        "μεγαλύτερη",
        "μεγαλείο",
        "πράσινος",
        "χαιρετισμός",
        "αγελαίος",
        "γκριμάτσα",
        "άλεσμα",
        "χαλίκι",
        "βάση",
        "καλλιεργώ",
        "ανάπτυξη",
        "εγγύηση",
        "φρουρά",
        "κηδεμόνας",
        "κηδεμονία",
        "κυβερνητικός",
        "οδηγία",
        "οδηγός",
        "οδηγός",
        "γκουρού",
        "εντόσθια",
        "γυμναστής",
        "βιότοπο",
        "υγιής",
        "εύχρηστος",
        "ευτυχώς",
        "ευτυχία",
        "ευτυχισμένος",
        "σκληραγωγημένος",
        "αρμονικά",
        "αρμονία",
        "συγκομιδή",
        "επίνειο",
        "πρόοδος",
        "θεραπεύω",
        "φαρμακευτικός",
        "υγιεινός",
        "υγιής",
        "εγκάρδιος",
        "εστία",
        "εγκάρδια",
        "ουράνιος",
        "ουράνια",
        "σηκώνω",
        "κράνος",
        "βοηθός",
        "βοηθητικός",
        "φυτικά",
        "ήρωας",
        "ηρωϊκός",
        "ηρωικά",
        "ηρωίδα",
        "ηρωϊσμός",
        "ακμή",
        "εύθυμος",
        "ιλαρότητα",
        "ενοικίαση",
        "χόμπι",
        "αργία",
        "αγιότητα",
        "άγιος",
        "φόρος τιμής",
        "ομολογία",
        "τίμιος",
        "τιμιότητα",
        "μέλι",
        "ΓΑΜΗΛΙΟ ΤΑΞΙΔΙ",
        "τιμή",
        "αξιότιμος",
        "ελπίδα",
        "ελπιδοφόρος",
        "ορίζοντας",
        "φιλοξενία",
        "νοικοκυριό",
        "νοικοκυριό",
        "αγκαλιάζω",
        "ανθρώπινος",
        "φιλάνθρωπος",
        "ανθρωπότητα",
        "ταπεινωμένος",
        "ταπεινά",
        "ταπεινότητα",
        "ευφυολόγος",
        "κωμικός",
        "Ζήτω",
        "γεωργία",
        "σιωπή",
        "καλύβα",
        "υγιεινός",
        "ύμνος",
        "ιδεαλισμός",
        "είδωλο",
        "NO TRANSLATION",
        "φωτισμός",
        "εικονογραφώ",
        "επιφανής",
        "ευφάνταστος",
        "άμωμος",
        "τεράστια",
        "βυθίζω",
        "αθάνατος",
        "μεταδίδω",
        "αμερόληπτος",
        "αμεροληψία",
        "άψογος",
        "αδιαπέραστος",
        "σημασια",
        "σπουδαίος",
        "εντυπωσιάζω",
        "εντύπωση",
        "βελτιώσει",
        "βελτίωση",
        "βελτίωση",
        "βελτίωση",
        "αυτοσχεδιάζω",
        "αναπαλλοτρίωτος",
        "εγκαίνια",
        "κοπτερός",
        "περιλαμβάνω",
        "περιλαμβάνεται",
        "συμπεριλαμβανομένου",
        "περιεκτικός",
        "αυξάνουν",
        "ανεξίτηλος",
        "αποζημίωση",
        "ανεξαρτησία",
        "άφθαρτος",
        "ατομικότητα",
        "αδάμαστος",
        "άφατος",
        "φτηνός",
        "αλάνθαστος",
        "βρέφος",
        "άπειρος",
        "άπειρο",
        "με επιρροή",
        "πληροφορίες",
        "ευφυής",
        "κληρονομία",
        "αμίμητος",
        "αθωότητα",
        "αθώος",
        "αθώα",
        "αβλαβής",
        "νεωτερίζω",
        "καινοτομία",
        "inquirer",
        "έρευνα",
        "περίεργος",
        "αρρηκτα συνδεδεμενα",
        "εμβλήματα",
        "επιθεωρητής",
        "έμπνευση",
        "εμπνέω",
        "εμπνευσμένος",
        "ενστικτώδης",
        "εντολή",
        "εντολή",
        "εκπαιδευτής",
        "ενόργανος",
        "ασφαλίζω",
        "άθικτος",
        "ακεραιότητα",
        "διάνοια",
        "διανοούμενος",
        "νοημοσύνη",
        "έξυπνος",
        "προορίζονται",
        "συνουσία",
        "ενδιαφέρον",
        "ενδιαφερόμενος",
        "ενδιαφέρων",
        "εσωτερικό",
        "προδικαστικός",
        "διάλειμμα",
        "οικείος",
        "τονισμός",
        "ατρόμητος",
        "διαίσθηση",
        "ενστικτώδης",
        "κατά κανόνα",
        "εφευρετικός",
        "εφευρέτης",
        "ερευνώ",
        "ενδυναμώνω",
        "πρόσκληση",
        "καλώ",
        "ελκυστικός",
        "σίδερο",
        "αμείωτος",
        "αδιάψευστος",
        "σύνολο στοιχημάτων",
        "μαρμελάδα",
        "NO TRANSLATION",
        "δουλειά",
        "Συμμετοχή",
        "εντάχθηκαν",
        "τζόκερ",
        "αστειεύεται",
        "δημοσιογράφος",
        "ταξίδι",
        "πρόσχαρος",
        "Χαρά",
        "χαρούμενος",
        "περιχαρής",
        "περιχαρής",
        "εορτή",
        "δικαστικός",
        "συνετός",
        "άλμα",
        "δικαιοσύνη",
        "δικαιολογημένος",
        "αιτιολόγηση",
        "ενθύμιο",
        "γνώση",
        "βασικός τόνος",
        "θεμέλιο",
        "είδος",
        "καλοσύνη",
        "συγγενείς",
        "Βασιλιάς",
        "φιλί",
        "γατάκι",
        "ικανότητα",
        "ιππότης",
        "γνωρίζων",
        "η γνώση",
        "δόξα",
        "εργασία",
        "αρνάκι",
        "γη",
        "προσγειώθηκε",
        "λέιζερ",
        "αξιέπαινος",
        "γέλιο",
        "γέλιο",
        "γέλιο",
        "εκτόξευση",
        "δαφνοστεφής",
        "δάφνη",
        "δάφνες",
        "πολυτελής",
        "νόμιμος",
        "οδηγω",
        "ηγέτης",
        "σύνδεσμος",
        "μαθαίνω",
        "μάθηση",
        "ομιλητής",
        "παρέκκλιση",
        "νομικός",
        "νομιμοποιηθεί",
        "μυθικός",
        "αναγνώσιμο",
        "ευανάγνωστος",
        "ελεύθερος χρόνος",
        "αβίαστος",
        "λεμμά",
        "επιεικής",
        "μάθημα",
        "λόγιος",
        "επίπεδο",
        "μόχλευση",
        "απελευθερώνω",
        "απελευθέρωση",
        "ελευθερία",
        "βιβλιοθήκη",
        "ζωή",
        "φάρος",
        "αρέσκεια",
        "γλωσσολόγος",
        "λιοντάρι",
        "ευκίνητος",
        "λογικός",
        "μακροζωία",
        "αρχοντιά",
        "αξιαγάπητος",
        "αγάπη",
        "ωραίος",
        "NO TRANSLATION",
        "εραστής",
        "τρυφερός",
        "πιστός",
        "αφοσίωση",
        "τυχη",
        "τυχερός",
        "γλυκύτατος",
        "λάμψη",
        "στιλπνός",
        "πλούσια",
        "πολυτελής",
        "πολυτέλεια",
        "Λύρα",
        "λυρικός",
        "μαγικός",
        "μαγνήτης",
        "μαγνητισμός",
        "μαγνητίτη",
        "μεγαλοπρέπεια",
        "μεγαλοπρεπής",
        "κόρη",
        "κύριος",
        "στυλοβάτης",
        "μεγαλοπρεπής",
        "μεγαλείο",
        "μείζων",
        "η πλειοψηφία",
        "διαχειρίζονται",
        "διαχείριση",
        "μανταρίνι",
        "ανδρική ηλικία",
        "εκδηλώθηκε",
        "ανδροπρεπής",
        "μάννα",
        "εξεζητημένος",
        "συμπεριφορά",
        "κατασκευαστής",
        "Μάρτιος",
        "μαρκαρισμένος",
        "πωλήσιμος",
        "μαρκήσιος",
        "γάμος",
        "μεδούλι",
        "παντρεύω",
        "διευθετώ",
        "θαύμα",
        "θαυμάσιος",
        "θαυμάσια",
        "αρρενωπός",
        "μασάζ",
        "κύριος",
        "αριστούργημα",
        "την κυριαρχία",
        "σύντροφος",
        "γάμος",
        "οικοδέσποινα",
        "ανώτατο όριο",
        "δήμαρχος",
        "λιβάδι",
        "μετρημένος",
        "μετάλλιο",
        "μεσιτεύω",
        "μεσολάβηση",
        "μεσολαβητής",
        "ιατρικός",
        "NO TRANSLATION",
        "μεσογειακός",
        "ποτ πουρί",
        "ενθύμιο",
        "αξιομνημόνευτος",
        "καρίκωμα",
        "έμμηνα",
        "μέντορας",
        "εύσπλαχνος",
        "έλεος",
        "συγχώνευση",
        "αξία",
        "άξιος",
        "ευθυμία",
        "εύθυμος",
        "μητροπολίτης",
        "θάρρος",
        "μικροσκοπία",
        "μαιευτική",
        "ισχυρός",
        "μίμος",
        "προσεκτικός",
        "νοημοσύνη",
        "Υπουργείο",
        "θαύμα",
        "θαυματουργός",
        "κέφι",
        "ιεραπόστολος",
        "μοντέλο",
        "μέτριος",
        "μεσολαβητής",
        "μετριόφρων",
        "σεμνότητα",
        "ορμή",
        "νομισματικός",
        "χρήματα",
        "καλόγερος",
        "μνημείο",
        "ηθικός",
        "ηθική",
        "ήθη",
        "γουδί",
        "μητρότητα",
        "κίνητρο",
        "κινητός",
        "υποκινητής",
        "μυώδης",
        "ΜΟΥΣΙΚΗ",
        "μιούζικαλ",
        "ευμετάβλητος",
        "αμοιβαίος",
        "υπνάκο",
        "φυσιοδίφης",
        "πλωτός",
        "νοικοκυρεμένα",
        "νέκταρ",
        "βελόνα",
        "διαπραγματεύομαι",
        "διαπραγματευτής",
        "γείτονας",
        "νεύρο",
        "φωλιάζω",
        "αρχοντιά",
        "ευγενής",
        "ευγενής",
        "υποψηφιότητα",
        "κανονικότητα",
        "αξιοσημείωτος",
        "αξιωματούχοι",
        "NO TRANSLATION",
        "έννοια",
        "θρέψη",
        "αριθμούς",
        "νοσοκόμα",
        "φυτώριο",
        "ανατροφή",
        "θρεπτικός",
        "δρυς",
        "όαση",
        "όρκος",
        "υπακοή",
        "σκοπός",
        "περιποιητικός",
        "παρατηρητικός",
        "εφικτός",
        "φανερός",
        "κάτοχος",
        "κατοχή",
        "ασχολούμαι",
        "προσφορά",
        "αξιωματικός",
        "αντισταθμίζεται",
        "παρακλάδι",
        "παντογνόστης",
        "ειλικρίνεια",
        "ΛΥΡΙΚΗ ΣΚΗΝΗ",
        "επίκαιρος",
        "ευκαιρία",
        "αισιοδοξία",
        "αισιόδοξος",
        "επιλογή",
        "προαιρετικός",
        "μαντείο",
        "λόγος",
        "ορχήστρα",
        "χειροτονήθηκε",
        "τακτικός",
        "χειροτονία",
        "οργανικός",
        "οργάνωση",
        "οργανώνω",
        "διοργάνωσε",
        "οργασμός",
        "πρωτοτυπία",
        "διακοσμημένα",
        "στολισμένος",
        "αποτέλεσμα",
        "υπερβαίνω",
        "προς τα έξω",
        "περιχαρής",
        "αφόρητος",
        "ιδιοκτησία",
        "ειρηνικός",
        "μπλοκ",
        "υλικό παραγεμίσματος",
        "κουπί",
        "εύγευστος",
        "πραϋντικό",
        "πανάκεια",
        "καμάρι",
        "NO TRANSLATION",
        "πάπρικα",
        "υπόδειγμα",
        "κυρίαρχος",
        "συγνώμη",
        "καταγωγή",
        "πλευρικός",
        "συμμετέχω",
        "συμμετοχή",
        "εταίρος",
        "συνεταιρισμός",
        "πάθος",
        "παθιασμένος",
        "απασχόληση",
        "πάστορας",
        "ζύμη",
        "βοσκή",
        "ευρεσιτεχνία",
        "υπομονή",
        "υπομονετικος",
        "πατριαρχικός",
        "προστάτης",
        "προστασία",
        "πληρωμή",
        "ειρήνη",
        "φιλήσυχος",
        "ειρηνικός",
        "παγώνι",
        "τσιμπώ",
        "ιδιορρυθμία",
        "γενεαλογικο δεντρο",
        "απαράμιλλος",
        "κλίση",
        "αντιλαμβάνομαι",
        "αντιληπτός",
        "αιωνόβιος",
        "τέλειος",
        "τελειότητα",
        "εκτελεστής",
        "ορθούμαι",
        "άδεια",
        "αιωνιότης",
        "επιμονή",
        "επίμονος",
        "ευπαρουσίαστος",
        "αρμόζων",
        "φαρμακευτικός",
        "φιλάνθρωπος",
        "φιλανθρωπία",
        "φιλόσοφος",
        "Φοίνιξ",
        "φωνητική",
        "γιατρός",
        "η φυσικη",
        "φισιολογία",
        "σωματική διάπλαση",
        "διαλέγω",
        "πικνίκ",
        "γραφικός",
        "ευσέβεια",
        "χάπι",
        "μαξιλάρι",
        "πιλότος",
        "κολοφών",
        "πρωτοπόρος",
        "ευσεβής",
        "ψίχα",
        "άξονας περιστροφής",
        "γαλήνιος",
        "σχεδίαση",
        "παιχνιδιάρικος",
        "παιδική χαρά",
        "θέατρο",
        "ευχάριστος",
        "ευχαριστημένος",
        "απολαυστικός",
        "ενέχυρο",
        "απόλυτος",
        "άφθονη",
        "πλέγμα",
        "δαμάσκηνο",
        "βαρίδι",
        "είδος βελούδου",
        "φύλλο",
        "επισήμως",
        "αστυνομία",
        "αστυνομικός",
        "στίλβωση",
        "άμεμπτος",
        "ευγενικός",
        "ευγένεια",
        "NO TRANSLATION",
        "πισίνα",
        "πάπας",
        "δημοτικότητα",
        "δημοφιλή",
        "πληθυσμός",
        "φορητός",
        "κατέχω",
        "πόσιμος",
        "δραστικότητα",
        "ισχυρός",
        "δυναμικά",
        "πρακτική",
        "εξασκημένος",
        "πρακτική",
        "έπαινος",
        "εξήρε",
        "αξιέπαινος",
        "προσεύχομαι",
        "προφύλαξη",
        "προηγούμαι",
        "προβάδισμα",
        "πολύτιμος",
        "ακριβής",
        "ακρίβεια",
        "προτίμηση",
        "επικρατέστερος",
        "διαπρεπής",
        "προτιμώ",
        "ΠΡΩΤΗ ΠΡΟΒΟΛΗ",
        "κτίριο",
        "προετοιμάζω",
        "έτοιμος",
        "προβλεπτικός",
        "παρουσία",
        "παρόν",
        "ευπαρουσίαστος",
        "συντηρητικό",
        "διατηρώ",
        "Πρόεδρος",
        "το κύρος",
        "γρήγορα",
        "αρκετά",
        "επικρατώ",
        "πρόληψη",
        "ανεκτιμητης ΑΞΙΑΣ",
        "υπερηφάνεια",
        "παπάς",
        "ιερατείο",
        "ιερατικός",
        "πρωτείο",
        "πρωταρχικός",
        "πρωταρχική",
        "αλφαβητάρι",
        "πρίγκιπας",
        "ηγεμονικός",
        "πριγκίπισσα",
        "ΔΙΕΥΘΥΝΤΡΙΑ σχολειου",
        "πρωτόγονος",
        "προνομιούχος",
        "ακεραιότητα",
        "διαδικασία",
        "πομπή",
        "κοσμήτορας",
        "προμηθεύω",
        "καταπληκτικός",
        "θαύμα",
        "παραγωγός",
        "παραγωγή",
        "παραγωγή",
        "παραγωγικός",
        "παραγωγικότητα",
        "επάγγελμα",
        "επαγγελματίας",
        "καθηγητής",
        "ικανότητα",
        "εντριβής",
        "άφθονος",
        "πρόοδος",
        "προχώρηση",
        "προοδευτικός",
        "γόνιμος",
        "προεξοχή",
        "εμφανώς",
        "υπόσχεση",
        "υποσχόμενος",
        "προβολή",
        "στήριγμα",
        "κατάλληλος",
        "προφήτης",
        "προφυλακτικό",
        "πρόταση",
        "προοπτική",
        "ευημερώ",
        "ευημερία",
        "επιτυχημένος",
        "προστατεύω",
        "προστασία",
        "προστατευτικός",
        "προστάτης",
        "υπερήφανος",
        "αποδεικνύω",
        "παροιμιώδης",
        "προμηθεύω",
        "χορήγηση",
        "σύνεση",
        "συνετός",
        "ψαλμός",
        "δημόσιο",
        "Τραβήξτε",
        "αμβώνας",
        "ακριβής",
        "ακρίβεια",
        "κουτάβι",
        "καθαρώς",
        "κάθαρση",
        "καθαρίζω",
        "καθαρολόγος",
        "καθαρότητα",
        "γουργούρισμα",
        "αλλόκοτος",
        "αρμόδιος",
        "προκριματικά",
        "αναζήτηση",
        "ερώτηση",
        "ταχύτητα",
        "ήρεμος",
        "ησυχια",
        "κινίνη",
        "ακτινοβολία",
        "ακτινοβόλος",
        "ακτινοβολώ",
        "ραδιόφωνο",
        "βυθισμένος",
        "έκσταση",
        "λογικός",
        "αναγνώστης",
        "πρόθυμα",
        "ετοιμότητα",
        "ΑΝΑΓΝΩΣΗ",
        "επαναβεβαιώ",
        "πραγματικός",
        "λόγος",
        "καθησύχαση",
        "καθησυχάζω",
        "έκπτωση",
        "ανάπλαση",
        "έλαβε",
        "λήψη",
        "NO TRANSLATION",
        "ανταποδίδω",
        "ανάκτηση",
        "πλαγιάζω",
        "ευκολογνώριστος",
        "συνιστώ",
        "συμφιλίωση",
        "αναθεώρηση",
        "επανακτίζω",
        "ανοικοδόμηση",
        "μηχάνημα εγγραφής",
        "αποζημιώ",
        "ανάκτηση",
        "αναψυχή",
        "ψυχαγωγικός",
        "επανορθώνω",
        "εξαγορά",
        "αποζημίωση",
        "εκκαθαρίζω",
        "διύλιση",
        "μεταρρύθμιση",
        "αναμόρφωση",
        "αναμορφωτής",
        "δροσιστικός",
        "στιλβώ πάλι",
        "βασιλικός",
        "αντιβασιλέας",
        "κανονικότητα",
        "ρυθμίζω",
        "αποκαθιστώ",
        "Αναμόρφωση",
        "αποζημιώ",
        "αποζημίωση",
        "ενίσχυση",
        "εγκαθιστώ πάλι",
        "χαίρομαι",
        "χαρά",
        "ξανανιώνω",
        "αναζωογόνηση",
        "χαλάρωση",
        "σχετικό",
        "αξιοπιστία",
        "αξιόπιστος",
        "εξάρτηση",
        "ανακούφιση",
        "ανακούφιση",
        "ξανακάνω",
        "αξιοσημείωτος",
        "NO TRANSLATION",
        "θεραπεία",
        "Άφεση",
        "μεταποιώ",
        "αναγέννηση",
        "καθιστώ",
        "ανανέωση",
        "ανακαινίζω",
        "ανακαίνιση",
        "φήμη",
        "περίφημος",
        "αναδιοργανώ",
        "αποζημίωση",
        "ανταποδίδω",
        "μετανοώ",
        "αναπληρώ",
        "γεμάτος",
        "δημοσιογράφος",
        "ανάπαυση",
        "αντιπροσωπεύεται",
        "αναπαραγωγικός",
        "ευυπόληπτος",
        "διάσωση",
        "Αποθεματικό",
        "Κάτοικος",
        "ελαστικός",
        "αντίσταση",
        "αποφασιστικά",
        "πόροι",
        "Σεβασμός",
        "ευπρέπεια",
        "αξιοσέβαστος",
        "γεμάτος σεβασμό",
        "σχετικά με",
        "σέβη",
        "αναβολή",
        "περίλαμπρος",
        "υπεύθυνος",
        "ευαίσθητος",
        "υπόλοιπο",
        "ξεκουραστικός",
        "αποκατάσταση",
        "τονωτικό",
        "αποκατάσταση",
        "συγκράτηση",
        "επανάληψη",
        "κράτηση",
        "επανένωση",
        "διασκεδάζω",
        "απολαμβάνει",
        "τιμώ",
        "ευλάβεια",
        "αιδεσιμότατος",
        "ονειροπόληση",
        "αναθεωρώ",
        "αναβίωση",
        "επαναστατικός",
        "ανταμοιβή",
        "ρυθμός",
        "ρυθμικός",
        "ταινία",
        "πλούτος",
        "καβαλάρης",
        "ενάρετος",
        "νόμιμος",
        "ορθά",
        "ώριμος",
        "ωριμάζω",
        "αυξανόμενες",
        "πριτσίνισμα",
        "ανοικτό αυτοκίνητο",
        "εύρωστος",
        "βράχος",
        "ράβδος",
        "διασκεδάζων θορυβωδώς",
        "ειδύλλιο",
        "ρομαντικός",
        "ρομαντισμός",
        "κάνω φασαρία",
        "ριζωμένος",
        "ρόδινος",
        "rota",
        "ρουτίνα",
        "βασιλεία",
        "ρουμπρίκα",
        "Ρουθ",
        "ασφαλής",
        "προστασία",
        "ΣΟΦΌΣ",
        "άγιος",
        "άγιος",
        "Μισθός",
        "προεξοχή",
        "σωτήριος",
        "χαιρετισμός",
        "σωτηρία",
        "αλοιφή",
        "σαμουράι",
        "αγιασμός",
        "αγιάζω",
        "άσυλο",
        "αισιόδοξος",
        "υγειονομικός",
        "σατέν",
        "ικανοποιητικά",
        "ικανοποιημένοι",
        "αποθηκεύσετε",
        "οικονομίες",
        "γεύση",
        "αλμυρά",
        "καταλαβαίνω",
        "λόγιος",
        "υποτροφία",
        "επιστημονικός",
        "επιστήμονας",
        "NO TRANSLATION",
        "σκορ",
        "γραφέας",
        "γραφή",
        "εξαίσιος",
        "γλυπτική",
        "θάλασσα",
        "σφραγίδα",
        "σκληραγωγημένος",
        "γραμματεία",
        "αρχαιότητα",
        "εντυπωσιακός",
        "έννοια",
        "ευαισθησία",
        "αισθητώς",
        "φιληδονία",
        "αισθησιακός",
        "αισθηματικός",
        "συναισθηματικότητα",
        "φρουρός",
        "ηρεμία",
        "κήρυγμα",
        "ορρός",
        "εγκαταστάτη",
        "φύλο",
        "σχήμα",
        "καλοφτιαγμένος",
        "μερίδιο",
        "καταφύγιο",
        "Βοσκός",
        "λάμψη",
        "λάμψη",
        "ψώνια",
        "ώμος",
        "πανούργος",
        "μετάξι",
        "απλοποιώ",
        "ειλικρινής",
        "ειλικρίνεια",
        "τραγουδώ",
        "χωριστά",
        "Κύριε",
        "αδελφότητα",
        "έμπειρος",
        "επιδέξιος",
        "ουρανός",
        "σχιστόλιθος",
        "λείος",
        "λεπτός",
        "λεπτός",
        "χαμόγελο",
        "χαμογελαστά",
        "χτυπημένος",
        "ομαλότητα",
        "χαχανίζω",
        "νηφαλιότητα",
        "κοινωνικός",
        "παρηγοριά",
        "στρατιώτης",
        "στερεός",
        "στερεότητα",
        "λύση",
        "φερεγγυότητα",
        "υποβρύχιο ραντάρ",
        "σονάτα",
        "σονέττο",
        "ηχηρός",
        "καλμάρω",
        "πραϋντικός",
        "NO TRANSLATION",
        "ορθότητα",
        "σούπα",
        "ιαματική πηγή",
        "ευρύχωρος",
        "σπανιέλ",
        "λάμπω",
        "ειδικός",
        "NO TRANSLATION",
        "ομιλία",
        "ταχύς",
        "ορθογραφία",
        "μπαχαρικό",
        "πνεύμα",
        "οινοπνευματώδη",
        "λαμπρός",
        "μεγαλείο",
        "ανάδοχος",
        "πεντακάθαρος",
        "σύζυγος",
        "έλατο",
        "σταθερός",
        "κοφτός",
        "ανοξείδωτος",
        "επιβήτορας",
        "παλληκάρι",
        "σθένος",
        "ορθοστασία",
        "αστέρι",
        "αστροφεγγιά",
        "έναστρος",
        "μεγαλοπρεπής",
        "δήλωση",
        "άγαλμα",
        "κατάσταση",
        "αφοσιωμένος",
        "σταθερός",
        "αστρικός",
        "οικονόμος",
        "ηρεμία",
        "κατάστημα",
        "ειλικρινής",
        "στρατηγική",
        "στρατηγός",
        "δύναμη",
        "ενισχύω",
        "τόνοση",
        "εκπληκτικός",
        "κτυπητά",
        "δυνατά",
        "δομή",
        "κουμπί κολάρου",
        "μελέτη",
        "ισχυρός",
        "εξάχνιση",
        "ουσία",
        "ουσιαστικό",
        "πετυχαίνω",
        "επιτυχία",
        "επιτυχία",
        "επιτυχής",
        "περιληπτικός",
        "επάρκεια",
        "ζάχαρη",
        "κατάλληλος",
        "αποπνικτικός",
        "ήλιος",
        "ηλιόλουστος",
        "η δυση του ηλιου",
        "λιακάδα",
        "υπέροχος",
        "υπεράνθρωπος",
        "ανώτερος",
        "υπεροχή",
        "υπεράνθρωπος",
        "σούπερ σταρ",
        "ικεσία",
        "προμήθειες",
        "Προμήθεια",
        "υποστηρίζεται",
        "υποστηρικτής",
        "υποστηρίζοντας",
        "ανώτατος",
        "υπερβολικά",
        "εγγύηση",
        "υποθέτω",
        "υπέροχος",
        "έκπληξη",
        "χωρομέτρηση",
        "επιζώ",
        "ορκίζομαι",
        "γλυκός",
        "Αγαπημένος",
        "γλυκιά μου",
        "γλύκα",
        "γλυκα",
        "ταχύς",
        "ζάλη",
        "συμβολικός",
        "συμμετρικός",
        "συμμετρία",
        "συμπονετικός",
        "συμπάθεια",
        "συμφωνία",
        "συγχρονίζω",
        "συνεργιστική",
        "σύνοδος",
        "λεπτότητα",
        "ιστορία",
        "ταλέντο",
        "φυλαχτό",
        "ΜΙΛΑ ρε",
        "μαυρισμένο",
        "έργο",
        "καλαίσθητος, έχων καλό γούστο",
        "γευστικός",
        "διδάσκω",
        "δάσκαλος",
        "τεχνολογία",
        "εγκράτεια",
        "καλόβουλος",
        "υποστηρίξιμος",
        "επίμονος",
        "επιμονή",
        "μίσθωση",
        "ενοικιαστής",
        "προσφορά",
        "τρυφερότητα",
        "ευγνώμων",
        "ευχαριστία",
        "θεωρητικός",
        "θεραπευτικός",
        "θεραπευτική",
        "NO TRANSLATION",
        "καθαρόαιμος",
        "προσεκτικός",
        "προσοχή",
        "λιτότης",
        "συγκίνηση",
        "συγκινητικός",
        "ευημερούν",
        "θρόνος",
        "γαργαλάω",
        "σκέπασμα με κεραμίδια",
        "έγκαιρος",
        "πούλιες",
        "τίτλος",
        "τοστ",
        "ανεκτικός",
        "ανεκτικότητα",
        "μπλουζα",
        "σκληρότητα",
        "πύργος",
        "πανυψηλός",
        "παραδοσιακός",
        "γαλήνιος",
        "γαλήνη",
        "υπέρβαση",
        "υπερφυσικός",
        "ταξίδια",
        "θησαυρός",
        "δέντρο",
        "τρομερά",
        "τάση",
        "μοντέρνο",
        "παραπόταμος",
        "φόρος",
        "κομψός",
        "θρίαμβος",
        "θριαμβευτικός",
        "τρόπαιο",
        "εκεχειρία",
        "ΑΛΗΘΗΣ",
        "έμπιστος",
        "αλήθεια",
        "φιλαλήθεια",
        "κηδεμονία",
        "παιδαγωγός",
        "δίδυμο",
        "ανοιγοκλείω τα βλέφαρα",
        "τελικά",
        "διαιτητής",
        "ομοφωνία",
        "ομόφωνος",
        "μετριόφρων",
        "αμερόληπτος",
        "άθραυστος",
        "άθραυστος",
        "αβίαστος",
        "υπογραμμίζω",
        "κατανόηση",
        "ασφαλίζω",
        "αδιαίρετος",
        "αθάνατος",
        "χωρίς αμφιβολία",
        "ξεδιπλωθεί",
        "ενοποίηση",
        "ομοιόμορφα",
        "μη μολυσμένο",
        "μοναδικός",
        "αρμονία",
        "ενιαία",
        "ενωμένος",
        "ενότητα",
        "πανεπιστήμιο",
        "απεριόριστος",
        "ταπεινός",
        "αναμφισβήτητος",
        "αναμφιβολώς",
        "αδιαμφισβήτητος",
        "αβλαβής",
        "ανιδιοτελής",
        "ανυπέρβατος",
        "ακλόνητος",
        "ανύψωση",
        "όρθιος",
        "χρησιμότητα",
        "κλητήρας",
        "συνήθης",
        "χρησιμότητα",
        "ουτοπικός",
        "διακοπές",
        "εμβόλιο",
        "ανδρείος",
        "NO TRANSLATION",
        "πολύτιμος",
        "εμπροσθοφυλακή",
        "καταβάλλω",
        "βελούδο",
        "βελουδένιος",
        "σεβάσμιος",
        "σεβασμός",
        "φιλαλήθεια",
        "χλοερός",
        "επαλήθευση",
        "επαληθεύτηκε",
        "αληθώς",
        "πραγματικός",
        "εαρινός",
        "οίστρος",
        "βετεράνος",
        "εφημέριος",
        "νικητής",
        "νικηφόρος",
        "νίκη",
        "επαγρύπνηση",
        "προσεχτικός",
        "σθένος",
        "σθεναρός",
        "χωρικός",
        "δικαιολογημένη",
        "δικαίωση",
        "παρθένα",
        "παρθενιά",
        "αρετή",
        "ενάρετος",
        "όραμα",
        "ονειροπόλος",
        "επίσκεψη",
        "επισκέπτης",
        "ζωτικής σημασίας",
        "ζωτικότητα",
        "ζωηρός",
        "ζωηρός",
        "λεξιλόγιο",
        "εθελοντής",
        "ηδονικός",
        "εγγυώμαι",
        "όρκος",
        "μισθοί",
        "εγγύηση",
        "πολεμιστής",
        "φρουρός",
        "προσεκτικός",
        "φρουρός",
        "αδιάβροχο",
        "πλούτος",
        "αδιάβροχος",
        "ευπρόσδεκτη",
        "άσπρο",
        "λευκότητα",
        "υγιεινός",
        "θυρίδα",
        "διαδεδομένη",
        "οικειοθελώς",
        "προθυμία",
        "αναπάντεχη τύχη",
        "νικητής",
        "επιτυχής",
        "κέρδη",
        "ασύρματος",
        "wis",
        "σοφία",
        "σοφός",
        "πνεύμα",
        "αντέχω",
        "wits",
        "πνευματώδης",
        "μάγος",
        "μήτρα",
        "εκπληκτικός",
        "υπέροχα",
        "θαυμαστός",
        "λέξη",
        "εργαζόμενος",
        "λατρεία",
        "αξία",
        "άξιος",
        "wot",
        "συγγραφέας",
        "νέος",
        "πιο ΝΕΟΣ",
        "νεολαία",
        "ζήλος",
        "ενθουσιώδης",
        "ζέση",
    ]
)

_negative = set(
    [
        "εγκαταλείπω",
        "εγκαταλειμμένος",
        "εγκατάλειψη",
        "απαγωγή",
        "ανώμαλος",
        "εκτροπή",
        "απεχθάνομαι",
        "απεχθής",
        "άθλιος",
        "ασυνήθιστος",
        "καταργώ",
        "κατάργηση",
        "απαίσιος",
        "βδέλυγμα",
        "αμβλώνω",
        "άμβλωση",
        "ανεπιτυχής",
        "τριβή",
        "ακυρώνω",
        "απόστημα",
        "απουσία",
        "απών",
        "απών",
        "κατά συνήθεια απουσία",
        "παράλογος",
        "παραλογισμός",
        "κατάχρηση",
        "αβυσσαλέες",
        "άβυσσος",
        "ατύχημα",
        "τυχαίος",
        "αθεόφοβος",
        "κατηγορία",
        "αιτιατική",
        "κατηγορούμενος",
        "κατήγορος",
        "κατηγορώντας",
        "πόνος",
        "οδυνηρός",
        "οξύ",
        "δικάσιμος",
        "αθροιστής",
        "εθισμός",
        "λιπώδης",
        "επιδικάζω",
        "νουθεσία",
        "ανεμοδαρμένος",
        "νοθευμένα",
        "μοιχεία",
        "αντίπαλος",
        "δυσμενής",
        "αντιξοότητα",
        "βασανίζω",
        "θρησκεία",
        "θλίψη",
        "προσβολή",
        "φοβισμένος",
        "συνέπεια",
        "επίγευση",
        "επιδεινωθεί",
        "επιδεινώνοντας",
        "επιδείνωση",
        "επίθεση",
        "επιθετικός",
        "επιδρομέας",
        "εμβρόντητος",
        "ταραγμένος",
        "ανακίνηση",
        "αγωνιώδης",
        "αγωνία",
        "καθισμένος",
        "πονώ",
        "ασθενής",
        "άσκοπος",
        "αέρα",
        "τρομάζω",
        "ανησυχητικός",
        "αλκοολισμός",
        "εξωγήινο",
        "απαλλοτριώ",
        "αποξενωμένος",
        "αποξένωση",
        "επίδομα διατροφής",
        "ισχυρισμός",
        "ισχυρίζομαι",
        "σε απόσταση",
        "φιλονικία",
        "ασαφής",
        "ενέδρα",
        "αμνησία",
        "αμφεταμίνες",
        "ανακόνδας",
        "πρωκτικός",
        "αναρχισμός",
        "αναρχικός",
        "αναρχία",
        "ανάθεμα",
        "αρχαίος",
        "θυμός",
        "κυνάγχη",
        "αγκιστεία",
        "θυμωμένος",
        "αγωνία",
        "έχθρα",
        "σκοπός",
        "εκμηδενίζω",
        "εξολοθρεύεται",
        "εκμηδένιση",
        "ενοχλώ",
        "ενόχληση",
        "ενοχλητικός",
        "ακυρώνω",
        "ακύρωση",
        "ανωμαλία",
        "Ανώνυμος",
        "ανταγωνισμός",
        "ανταγωνιστής",
        "ανταγωνιστικός",
        "άνθρακας",
        "αντίχριστος",
        "αντιπάθεια",
        "απηρχαιωμένος",
        "αντικοινωνικός",
        "αντίθεση",
        "ανησυχία",
        "ανήσυχος",
        "απάχης",
        "απαθής",
        "απάθεια",
        "ψείρα των φυτών",
        "τρομακτικός",
        "σκωληκοειδίτιδα",
        "σύλληψη",
        "φοβισμένος",
        "οικειοποίηση",
        "αρχαϊκός",
        "επίπονος",
        "λογομαχώ",
        "διαφωνία",
        "διαλεκτικός",
        "ξερός",
        "εξοπλισμού",
        "κλήση",
        "καθυστερούμενα",
        "σύλληψη",
        "αλαζονεία",
        "αλαζονικός",
        "αρσενικό",
        "εμπρησμός",
        "πυροβολικό",
        "φλαμουριά",
        "ντροπιασμένος",
        "τέφρα",
        "γάιδαρος",
        "προσβάλλω",
        "επιτιθεμένος",
        "δολοφόνος",
        "δολοφονώ",
        "δολοφονία",
        "προσβολή",
        "κώλος",
        "παραστρατημένος",
        "στυπτικός",
        "άσυλο",
        "αθεϊσμός",
        "αθηροσκλήρωση",
        "φρικτός",
        "θηριωδία",
        "ατροφία",
        "επίθεση",
        "επίθεση",
        "εξασθενημένο",
        "απόσβεση",
        "θράσος",
        "λιτός",
        "λιτότητα",
        "αυταρχικός",
        "αυτοψία",
        "χιονοστιβάδα",
        "φιλαργυρία",
        "εκδικητής",
        "ακούσιος",
        "αποστροφή",
        "αποφύγει",
        "αποφυγή",
        "απαίσιος",
        "αδεξιότητα",
        "στραβά",
        "φλυαρία",
        "φλυαρία",
        "βαβουίνος",
        "οπισθοδρομικός",
        "προς τα πίσω",
        "ύδατα πίσω από διάφραγμα",
        "βακτήρια",
        "NO TRANSLATION",
        "κακό",
        "ασβός",
        "κακώς",
        "κακία",
        "δικαστικός κλητήρας",
        "δόλωμα",
        "μπάλλα",
        "παρεμποδίζω",
        "NO TRANSLATION",
        "ληστής",
        "όλεθρος",
        "πάταγος",
        "banger",
        "εξορίζω",
        "εκτοπισμένοι",
        "εξορία",
        "χρεωκοπημένος",
        "πτώχευση",
        "banshee",
        "barb",
        "βάρβαρος",
        "βαρβαρικός",
        "βαρβαρισμός",
        "φλοιός",
        "αποκλεισμένη",
        "άγονος",
        "οδόφραγμα",
        "εμπόδιο",
        "αβάσιμη",
        "μπάσταρδος",
        "ροπαλοφόρος",
        "κακοποιημένα",
        "μπαταρία",
        "μάχη",
        "μάχεται",
        "πεδίο μάχης",
        "ανήθικος",
        "ξιφολόγχη",
        "φορέας",
        "θηρίο",
        "κτηνώδης",
        "χτύπημα",
        "συμβαίνω",
        "ικετεύω",
        "ζητιάνος",
        "επαιτεία",
        "μεγαθήριο",
        "ευγνώμων",
        "καθυστερημένος",
        "υποτιμώ",
        "εμπόλεμος",
        "ζώνη",
        "κλίνων",
        "τεθλιμμένος",
        "πένθος",
        "στερημένος",
        "έξω φρενών",
        "κτηνώδης",
        "προδίδω",
        "προδοσία",
        "Προσοχή",
        "μπερδεμένος",
        "προκατάληψη",
        "μεροληπτική",
        "διαμαρτυρία",
        "NO TRANSLATION",
        "φανατικός",
        "φανατικός",
        "χολή",
        "βιοψία",
        "σημύδα",
        "γενέτειρα",
        "σκύλα",
        "δάγκωμα",
        "πικρά",
        "πικρία",
        "παράξενος",
        "μαύρος",
        "κοντό ρόπαλο δεμένο με λουρί",
        "εκβιασμός",
        "μαυρίλα",
        "κατηγορώ",
        "ήπιος",
        "βλάσφημος",
        "βλασφημία",
        "έκρηξη",
        "κραυγαλέος",
        "blather",
        "φλόγα",
        "ψυχρός",
        "Αιμορραγία",
        "ψεγάδι",
        "ερυσίβη",
        "καταστρέφονται",
        "τυφλός",
        "τυφλή",
        "με κλειστά μάτια",
        "τύφλωση",
        "φουσκάλα",
        "πρησμένος",
        "άμορφη μάζα",
        "αποκλεισμός",
        "αιματοχυσία",
        "αιμοδίψης",
        "αιματηρός",
        "κηλίδα",
        "φυσητήρας",
        "έκρηξη",
        "ακεφιά",
        "μπλόφα",
        "γκάφα",
        "θολούρα",
        "θολός",
        "κοκκινίζω",
        "με καυχη",
        "τελματώ",
        "ψευδής",
        "βρασμός",
        "μπόιλερ",
        "βόμβα",
        "βομβαρδίζω",
        "βομβαρδισμός",
        "βομβαρδίστηκε",
        "δουλεία",
        "δεσμούς",
        "γιούχα",
        "μπούφος",
        "μεθοκοπώ",
        "NO TRANSLATION",
        "ανία",
        "βαρετό",
        "οφειλέτης",
        "ενόχληση",
        "ενοχλεί",
        "κάτω μέρος",
        "όριο",
        "πάλη",
        "βοδινός",
        "αγόρι",
        "μποϋκοτάζ",
        "καυχιέμαι",
        "κονιάκ",
        "νταηλίκι",
        "φιλονικία",
        "ορειχάλκινος",
        "αθέτηση",
        "έπαθε βλάβη",
        "ιλιγγιώδης",
        "NO TRANSLATION",
        "δωροδοκία",
        "δωροδοκία",
        "ταξιαρχία",
        "θειάφι",
        "γουρουνότριχα",
        "ομοβροντία",
        "ψήνω στη σχάρα",
        "έσπασε",
        "σπασμένος",
        "πορνείο",
        "μώλωπας",
        "ορμή",
        "κτηνώδης",
        "κτηνωδία",
        "κτήνος",
        "μπουφές",
        "έντομο",
        "NO TRANSLATION",
        "βολβοειδής",
        "νταής",
        "αλήτης",
        "bummer",
        "επαχθής",
        "γραφειοκρατία",
        "γραφειοκράτης",
        "διαρρήκτης",
        "διάρρηξη",
        "ταφή",
        "θάβονται",
        "burke",
        "κάηκε",
        "σπάσει",
        "σφάζω",
        "βαρέλι",
        "buzzed",
        "κλίκα",
        "κακοφωνία",
        "παληάνθρωπος",
        "πτώμα",
        "κλουβί",
        "υπολογιστικός",
        "NO TRANSLATION",
        "κλήσεις",
        "εκστρατεία",
        "Ματαίωση",
        "Καρκίνος",
        "σαράκι",
        "ανθρωποφάγος",
        "καννιβαλισμός",
        "NO TRANSLATION",
        "αιχμάλωτος",
        "αιχμαλωσία",
        "αιχμαλωτίζων",
        "πιάνω",
        "σκελετός",
        "καρκίνωμα",
        "καρδιομυοπάθεια",
        "απροσεξία",
        "καρικατούρα",
        "τερηδόνα",
        "σφαγή",
        "σαρκικός",
        "σαρκοφάγος",
        "καρτέλ",
        "υπόθεση",
        "φέρετρο",
        "κοινωνική τάξη",
        "ατύχημα",
        "καταρράκτης",
        "καταστροφή",
        "καθετήρας",
        "Προσοχή",
        "παραχωρώ",
        "νεκροταφείο",
        "λογοκριτής",
        "μομφή",
        "ς",
        "παύση",
        "άχυρο",
        "φθορά",
        "πικρία",
        "πρόκληση",
        "χάος",
        "χαώδης",
        "συλλαβόγριφος",
        "επιβαρυνόμενος",
        "κυνηγητό",
        "τιμωρία",
        "ομιλητικός",
        "φτηνός",
        "απάτη",
        "τσεισκέικ",
        "chicane",
        "παιδαριώδης",
        "ψυχρός",
        "χλωροφόρμιο",
        "πνιγομαι",
        "χολέρα",
        "μπριζόλα",
        "αγγαρεία",
        "χρόνιος",
        "τσιγάρο",
        "κραυγή",
        "σύγκρουση",
        "σύγκρουση",
        "δαγκάνα",
        "μοναστήρι",
        "θολός",
        "συννεφιά",
        "συστάδα δέντρων",
        "αδέξιος",
        "κοκαΐνη",
        "αναγκάζω",
        "εξαναγκασμός",
        "φέρετρο",
        "κρύο",
        "ψυχρά",
        "ψυχρότητα",
        "κολικός",
        "κατάρρευση",
        "σύγκρουση",
        "συμπαιγνία",
        "κώμα",
        "κωματώδης",
        "μάχη",
        "πολεμιστής",
        "μαχητικός",
        "ανάθεση",
        "αναταραχή",
        "κομμουνισμός",
        "κομμουνιστικός",
        "ανταγωνισμός",
        "κανω παραπονα",
        "καταγγελία",
        "συγκροτημένο",
        "περίπλοκο",
        "περιπλέκω",
        "περίπλοκος",
        "επιπλοκή",
        "κοπρόχωμα",
        "καταναγκασμός",
        "υποχρεωτικός",
        "κρύβουν",
        "απόκρυψη",
        "απόκρυψη",
        "έπαρση",
        "ματαιόδοξος",
        "διάσειση",
        "καταδικάζω",
        "καταδίκη",
        "καταδεκτικός",
        "συγκατάβαση",
        "ομολογία",
        "περιορίζω",
        "περιορισμένος",
        "περιορισμός",
        "κατάσχω",
        "κατάσχεση",
        "πυρκαγιά",
        "σύγκρουση",
        "αντιφατικός",
        "κατατροπώνω",
        "καταραμένος",
        "συγχέω",
        "σύγχυση",
        "συμφόρηση",
        "εξαναγκάζοντας",
        "κατάκτηση",
        "συνωμότης",
        "συνωμοτώ",
        "κατάπληξη",
        "δυσκοιλιότητα",
        "περιορίζω",
        "περιορισμένες",
        "περιορισμός",
        "μετάδοση",
        "μεταδοτικός",
        "μολύνω",
        "μολυσμένο",
        "μόλυνση",
        "περιφρόνηση",
        "ποταπός",
        "περιφρονητικός",
        "φιλόνικος",
        "λαθρεμπόριο",
        "συνεσταλμένος",
        "διαψεύδω",
        "αντίφαση",
        "αντιφατικός",
        "αντίθετος",
        "αντίθετα",
        "εναντιούμαι",
        "παράβαση",
        "αμφιλεγόμενος",
        "αμφισβήτηση",
        "κατάδικος",
        "καταδίκη",
        "κοτέτσι",
        "αντίγραφο",
        "copycat",
        "δικαστής ερευνών",
        "δεκανέας",
        "πτώμα",
        "διόρθωση",
        "διάβρωση",
        "διαβρωτικός",
        "διεφθαρμένος",
        "καταστρέφοντας",
        "διαφθορά",
        "βήχας",
        "σύμβουλος",
        "coursing",
        "επιθυμώ",
        "δειλός",
        "δειλία",
        "δειλά",
        "crabby",
        "ρωγμή",
        "Ραγισμένο",
        "ράγισμα",
        "κράμπα",
        "πυκνός",
        "μανιβέλα",
        "εκκεντρικός",
        "σκατά",
        "σύγκρουση",
        "αργή πορεία",
        "τρελό",
        "τρελός",
        "σκασίματα",
        "πλάσμα",
        "ανατριχιάζω",
        "έγκλημα",
        "εγκληματίας",
        "εγκληματικότητα",
        "μαζεύομαι",
        "σακατεύω",
        "αναστατωμένος",
        "κρίση",
        "τραγανός",
        "κριτικός",
        "κριτική",
        "κριτικάρω",
        "απατεώνας",
        "σταυρός",
        "σκύψιμο",
        "ο σταυρός",
        "σταύρωση",
        "ακατέργαστος",
        "σκληρός",
        "σκληρά",
        "σκληρότητα",
        "θρυμματισμός",
        "τραγάνισμα",
        "σταυροφορία",
        "συνθλίβονται",
        "συντριπτικός",
        "κακότροπος",
        "κραυγή",
        "κλαίων",
        "κρύπτη",
        "κερατάς",
        "κούκος",
        "εκλογή",
        "ενοχή",
        "υπαίτιος",
        "ένοχος",
        "λατρεία",
        "δυσκίνητος",
        "βεντούζα",
        "κοπρίτης",
        "κατάρα",
        "καταραμένος",
        "κατάρα",
        "βιαστικός",
        "κόπτης",
        "cutthroat",
        "τομή",
        "κυανιούχο",
        "κυκλώνας",
        "κύστη",
        "κυτταρομεγαλοϊό",
        "αδέξιος",
        "δαίμονας",
        "τρελός",
        "στιλέτο",
        "βλάβη",
        "αποζημίωση",
        "δεκάρα",
        "καταδίκη",
        "καταραμένος",
        "αποσβεστήρας",
        "πιτυρίδα",
        "δανδής",
        "κίνδυνος",
        "επικίνδυνος",
        "αμαυρώνω",
        "σκοτεινό",
        "σκοτάδι",
        "διακεκομμένη",
        "ποταπός",
        "ζαλισμένος",
        "απενεργοποιήστε",
        "αδιέξοδο",
        "θανάσιμα",
        "κουφός",
        "θάνατος",
        "πανωλεθρία",
        "κραιπάλη",
        "συντρίμμια",
        "χρέος",
        "οφειλέτης",
        "φθορά",
        "καταστράφηκε",
        "μακαρίτης",
        "απάτη",
        "δόλιος",
        "εξαπατώ",
        "εξαπάτησε",
        "εξαπατώντας",
        "εξαπάτηση",
        "απατηλός",
        "απόκλιση",
        "πτώση",
        "μειώνεται",
        "αποσύνθεση",
        "μείωση",
        "μείωση",
        "υπέργηρος",
        "κατηγορώ",
        "αφαιρώ",
        "δυσφήμηση",
        "δυσφημηστικός",
        "Προκαθορισμένο",
        "ήττα",
        "νίκησε",
        "ελάττωμα",
        "NO TRANSLATION",
        "ελαττωματικός",
        "ανυπεράσπιστος",
        "αναβολή",
        "περιφρόνηση",
        "προκλητικός",
        "έλλειψη",
        "έλλειμμα",
        "υποτιμώ",
        "ξεφούσκωμα",
        "παραμόρφωση",
        "παραμορφωμένος",
        "παραμόρφωση",
        "εξαπατώ",
        "μακαρίτης",
        "προκαλώ",
        "εκφυλισμό",
        "εκφυλισμένος",
        "υποβιβασμός",
        "υποβιβάζω",
        "απογοητευτικό",
        "καθυστέρηση",
        "καθυστέρηση",
        "επιβλαβής",
        "διαγραφή",
        "εγκληματικότητα",
        "εγκληματίας",
        "έξαλλος",
        "παραλήρημα",
        "κατακλυσμός",
        "αυταπάτη",
        "παραπλανητική",
        "ζήτηση",
        "απαιτητική",
        "παράφρων",
        "άνοια",
        "θάνατος",
        "κατεδαφίζω",
        "κατεδάφιση",
        "δαίμονας",
        "δαιμονικός",
        "απογοητευμένοι",
        "άρνηση",
        "αρνήθηκε",
        "καταγγέλω",
        "καταγγελία",
        "αρνούμαι",
        "αρνούμενος",
        "περασμένος",
        "αναχώρηση",
        "ΕΞΑΡΤΗΣΗ",
        "εξάρτηση",
        "αξιοθρήνητος",
        "θρηνώ",
        "απελαύνω",
        "απέλαση",
        "διεφθαρμένος",
        "διαφθορά",
        "υποτιμώ",
        "υποτιμήθηκε",
        "υποτίμηση",
        "καταπιέζω",
        "μελαγχολικός",
        "κατάθλιψη",
        "κατάθλιψη",
        "καταθλιπτικό",
        "στέρηση",
        "διαταραχές",
        "εγκαταλελειμένος",
        "χλευασμός",
        "προσβολή",
        "υποτιμητικός",
        "βεβήλωση",
        "έρημος",
        "έρημο",
        "λιποταξία",
        "απέχω",
        "ερήμωση",
        "απελπισία",
        "απελπισμένος",
        "απελπισμένος",
        "ποταπός",
        "NO TRANSLATION",
        "αυταρχικός",
        "δεσποτισμός",
        "άπορος",
        "καταστράφηκε από",
        "αντιτορπιλικό",
        "καταστρέφοντας",
        "καταστροφή",
        "καταστρεπτικός",
        "απόσπαση",
        "καθυστερώ",
        "κρατούμενο",
        "κράτηση στη φυλακή",
        "χειροτερεύω",
        "επιδεινωθεί",
        "αλλοίωση",
        "αντιπαθώ",
        "εκπυρσοκροτώ",
        "αφαιρώ",
        "βλάβη",
        "επιβλαβής",
        "τρίμματα",
        "ερημώνω",
        "καταστροφικά",
        "καταστροφή",
        "διάβολος",
        "διαβολικός",
        "εκτρεπόμενος",
        "μεταβίβαση",
        "καταβροχθίζω",
        "διαβολικός",
        "διάγνωση",
        "λίβελλος",
        "δικτάτορας",
        "δικτατορικός",
        "δικτατορία",
        "NO TRANSLATION",
        "δυσκολίες",
        "δυσκολία",
        "εκτρέπομαι",
        "σαραβαλιασμένος",
        "αραιωμένος",
        "ελαττώνω",
        "μειώθηκε",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "βρωμιά",
        "βρώμικος",
        "αναπηρία",
        "καθιστώ ανίκανο",
        "άτομα με ειδικές ανάγκες",
        "δυσαρεστημένος",
        "διαφωνώ",
        "διαφωνώ",
        "διαφωνία",
        "απορρίφθηκε",
        "απογοητεύω",
        "απογοητευμένος",
        "απογοητευτικός",
        "απογοήτευση",
        "αποδοκιμασία",
        "αποδοκιμάζω",
        "απορρίφθηκε",
        "απορρίπτοντας",
        "καταστροφή",
        "καταστρεπτικός",
        "δυσπιστώ",
        "απορρίψεις",
        "εκπλήρωση",
        "πειθαρχία",
        "αρνούμαι",
        "αποχρωματισμός",
        "ξεθωριασμένος",
        "δυσφορία",
        "αποσυνδέω",
        "ασύνδετος",
        "αποσύνδεση",
        "δυσαρέσκεια",
        "διακόπτω",
        "ασυνέχεια",
        "διχόνοια",
        "αποθαρρύνουν",
        "αποθάρρυνση",
        "κακοσυνιστώ",
        "κανω διακρισεις",
        "οξυδερκής",
        "διάκριση",
        "περιφρονώ",
        "ασθένεια",
        "νόσων",
        "άϋλος",
        "αποσύνδεση",
        "παραμορφωμένο",
        "ντροπή",
        "NO TRANSLATION",
        "αισχρός",
        "θυμωμένος",
        "αηδία",
        "αηδιαστικός",
        "απογοητευμένοι",
        "απογοητευτικό",
        "ανέντιμος",
        "ατιμία",
        "ατιμία",
        "απογοήτευση",
        "παραπληροφόρηση",
        "ανειλικρινής",
        "αποσυνθέτω",
        "αποσύνθεση",
        "αφιλοκερδής",
        "αντιπάθεια",
        "Αντιπαθής",
        "απομακρύνεται",
        "μελαγχολικός",
        "φόβος",
        "διαμελισμός",
        "απόλυση",
        "ανυπακοή",
        "ανυπάκουος",
        "απειθώ",
        "διαταραχή",
        "άτακτα",
        "αποδιοργανωμένη",
        "δυσφημώ",
        "δυσφημιστικός",
        "ανισότητα",
        "ψύχραιμος",
        "διασκορπίζω",
        "διασπορά",
        "εκτοπίζω",
        "μη ικανοποιημένοι",
        "δυσαρέσκεια",
        "διάθεση",
        "εκδιώχθηκε",
        "διαμάχη",
        "ανικανότητα",
        "αποκλεισμένη",
        "καθιστώ ακατάλληλο",
        "αμέλεια",
        "αγνοείται",
        "ανυπόληπτος",
        "έλλειψη σεβασμού",
        "ασεβής",
        "αναστάτωση",
        "δυσαρέσκεια",
        "διαφωνία",
        "διαφωνώντας",
        "κακή υπηρεσία",
        "διαφωνών",
        "διάλυση",
        "παραφωνία",
        "αποστροφή",
        "αηδιαστικός",
        "διεστραμμένος",
        "παραμόρφωση",
        "αποσπώ",
        "αποσπάται",
        "αποσπά την προσοχή",
        "ΑΠΟΣΠΑΣΗ",
        "τρελός",
        "δυσφορία",
        "αγχωμένος",
        "δυστυχώς",
        "δυσπιστία",
        "διατάραξη",
        "διαταραχθεί",
        "αχρηστία",
        "να εγκαταλειφθεί",
        "αποκλίνων",
        "εκποιηθούν",
        "εκποίηση",
        "διαζύγιο",
        "ζάλη",
        "ζαλισμένος",
        "αγκυροβόλησε",
        "NO TRANSLATION",
        "απογοητεύσεις",
        "βοήθημα ανεργίας",
        "NO TRANSLATION",
        "κυρίαρχο",
        "κυριαρχία",
        "Γάιδαρος",
        "γράφω άσκοπα",
        "μοίρα",
        "καταδικασμένος",
        "ημέρα της κρίσης",
        "αμφιβολία",
        "αμφίβολος",
        "αμφιβολίες",
        "ντους",
        "κατηφής",
        "ξεπεσμός",
        "παλιογυναίκα",
        "αποχέτευση-απορροή",
        "μειονέκτημα",
        "φόβος",
        "φοβερός",
        "τρομακτικά",
        "θλιβερός",
        "πίνω",
        "μωρολογία",
        "κηφήνας",
        "χτύπημα",
        "ξηρασία",
        "πνίγω",
        "υπνηλία",
        "ελεεινή εργασία",
        "μεθυσμένος",
        "μεθυσμένος",
        "αμφίβολος",
        "αμβλύς",
        "χαζός",
        "ανδρείκελο",
        "κατήφεια",
        "γκριζόμαυρος",
        "μπουντρούμι",
        "κοροϊδεύω",
        "διπροσωπία",
        "απειλή",
        "σκόνη",
        "νάρκη",
        "βαφή",
        "δυσεντερία",
        "σεισμός",
        "υποκλοπή",
        "διάταγμα",
        "θηλυπρεπής",
        "εγωιστική",
        "διαβόητος",
        "εκβάλλω",
        "εκτίναξη",
        "εξάλειψη",
        "άπιαστος",
        "αδυνατισμένος",
        "NO TRANSLATION",
        "στενοχωρώ",
        "στενόχωρος",
        "αμηχανία",
        "υπεξαίρεση",
        "εμβολισμός",
        "εμπλοκή",
        "επείγον",
        "θύλακας",
        "καταπάτηση",
        "επιβάρυνση",
        "διακινδυνεύω",
        "υπο ΕΞΑΦΑΝΙΣΗ",
        "ενδημικός",
        "εχθρός",
        "επιβολή",
        "αινιγματικός",
        "εχθρότητα",
        "υποδουλώνω",
        "υπόδουλος",
        "υποδούλωση",
        "εμπλοκή",
        "μπλέξιμο",
        "εντόσθια ζώου",
        "ζηλιάρης",
        "επιδημία",
        "επιληψία",
        "εκρίζω",
        "εκρίζωση",
        "εξάλειψη",
        "διάβρωση",
        "πλανώμαι",
        "πλανόδιος",
        "ασταθής",
        "erratum",
        "σφαλμένος",
        "λάθος",
        "εκρήγνυμαι",
        "έκρηξη",
        "κλιμακώνω",
        "αποφεύγω",
        "κατασκοπεία",
        "αποξενωμένοι",
        "ευθανασία",
        "αδειάζω",
        "κένωση",
        "αποφεύγω",
        "υπεκφυγή",
        "κάνω έξωση",
        "έξωση",
        "κακό",
        "ερεθίζω",
        "παρόξυνση",
        "απαιτητικός",
        "υπερβάλλω",
        "εξωγκωμένος",
        "εξέταση",
        "εξόργιση",
        "ανασκαφή",
        "υπέρβαση",
        "έμμεσος φόρος",
        "εξαιρούνται",
        "με εξαίρεση",
        "αποκλεισμός",
        "κόπρανα",
        "ανυπόφορος",
        "δικαιολογία",
        "εκτέλεση",
        "δήμιος",
        "εξάτμιση",
        "εξαντλημένος",
        "εξάντληση",
        "NO TRANSLATION",
        "εξορία",
        "εξορκισμός",
        "εκπατρισμένος",
        "αποβάλλω",
        "δαπάνη",
        "έξοδα",
        "εκπνέω",
        "έχει λήξει",
        "βλαστήμια",
        "εκραγεί",
        "έκρηξη",
        "εκρηκτικός",
        "εκτεθειμένος",
        "απαλλοτρίωση",
        "απέλαση",
        "εξολοθρεύω",
        "εξόντωση",
        "εξαφανισμένος",
        "σβήνω",
        "εξωδικός",
        "άκρο",
        "κατασκευάζω",
        "κατασκεύασμα",
        "ξεθωριάζει",
        "κόπρανα",
        "έλλειψη",
        "αποτυχία",
        "λιποθυμία",
        "άπιστος",
        "απομίμηση",
        "πτώση",
        "απατηλός",
        "πλάνη",
        "σφαλερός",
        "πτώση",
        "κιτρινωπός",
        "ψεύδος",
        "ψευδώς",
        "παραποίηση",
        "νοθεύω",
        "ψευτιά",
        "διστάζω",
        "πείνα",
        "φανατικός",
        "φάρσα",
        "κωμικός",
        "νηστεία",
        "Λίπος",
        "μοιραίος",
        "μοιραίο",
        "μοίρα",
        "κούραση",
        "κουρασμένος",
        "λιπαρός",
        "σφάλμα",
        "ελαττωματικός",
        "ελαφάκι",
        "φόβος",
        "φοβερός",
        "με φόβο",
        "φοβούμενοι",
        "εμπύρετος",
        "κοπράνων",
        "περιττώματα",
        "τέλη",
        "αδύνατος",
        "υπερηφάνεια",
        "τομάρι ζώου",
        "παρανυχίδα",
        "κακούργημα",
        "ένζυμο",
        "άγριος",
        "αγριότητα",
        "έχθρα",
        "φεουδαρχικός",
        "φεουδαρχία",
        "πυρετώδης",
        "φιάσκο",
        "ψεματάκι",
        "άστατος",
        "πλασματικός",
        "δαίμονας",
        "άγριος",
        "πάλη",
        "μαχητικός",
        "πολιτική κωλυσιεργία",
        "βρώμα",
        "ακάθαρτος",
        "πυροβόλα όπλα",
        "ταιριάζει",
        "πλαδαρός",
        "χαλαρός",
        "κύπτων πεζοδρόμιο",
        "σκανδαλώδης",
        "νιφάδα",
        "πτερύγιο",
        "φούσκωμα",
        "καμαρώνω",
        "ελάττωμα",
        "ψύλλος",
        "NO TRANSLATION",
        "μαλλί",
        "σαρκώδης",
        "δειλιάζω",
        "δέρνω",
        "πτώση",
        "πλευρονήκτης",
        "γρίπη",
        "διακύμανση",
        "εχθρός",
        "αποφευχθεί",
        "τρέλα",
        "ανόητος",
        "ανόητος",
        "ανοησία",
        "βοσκή",
        "επιδρομή",
        "απαγορεύω",
        "αποκρουστικός",
        "δύναμη",
        "εξαναγκασμένος",
        "βίαια",
        "προαίσθημα",
        "κατάσχω",
        "προηγούμαι",
        "ξένο",
        "ξένος",
        "προειδοποίησε",
        "τίμημα",
        "καταπέσει",
        "κατάσχεση",
        "πλαστογραφία",
        "ξεχνάμε",
        "ξεχασμένος",
        "ελεεινός",
        "άμορφος",
        "πορνεία",
        "αφήνω",
        "εγκαταλείφθηκε",
        "βρωμερός",
        "κάταγμα",
        "εύθραυστο",
        "αδυναμία",
        "μανιώδης",
        "απάτη",
        "απατηλός",
        "γεμάτος",
        "συμπλοκή",
        "αποτρίχωση",
        "παράξενος",
        "πάγωμα",
        "ξέφρενος",
        "ξέφρενος",
        "φρενίτιδα",
        "εκνευρίζομαι",
        "τρομάρα",
        "τρομάζω",
        "τρομαγμένα",
        "τρομερός",
        "ψυχρός",
        "επιπόλαιος",
        "κρυοπάγημα",
        "αφρός",
        "συνοφρυώνομαι",
        "φαίνοντα",
        "άκαρπος",
        "αγανακτώ",
        "απογοητευμένοι",
        "εκνευρισμός",
        "μωρολογώ",
        "φυγάς",
        "ψηλαφώ",
        "καπνός",
        "καπνίζοντας",
        "μύκητας",
        "φόβος",
        "έξαλλος",
        "παραφορά",
        "μανία",
        "φασαρία",
        "γκρινιάρης",
        "μάταιος",
        "ματαιοπονία",
        "gaby",
        "φίμωτρο",
        "χολή",
        "αγχόνη",
        "τζόγος",
        "χαρτοπαίχτης",
        "ΤΥΧΕΡΑ ΠΑΙΧΝΙΔΙΑ",
        "συμμορία",
        "φυλακή",
        "χάσμα",
        "σκουπίδια",
        "φανταχτερός",
        "γαρνιτούρα",
        "βαθειά πληγή",
        "αναπνοή",
        "NO TRANSLATION",
        "λιπόσαρκος",
        "ευγενής",
        "γηριατρική",
        "φρικτός",
        "γκέττο",
        "πνευματικός",
        "ασυναρτησίες",
        "παγετώδης",
        "αντηλιά",
        "καταφανής",
        "ετοιμόλογος",
        "κατήφεια",
        "ζοφερός",
        "σκυθρωπός",
        "κόρος",
        "λαιμαργία",
        "νάνος",
        "δαιμόνιο",
        "άθεος",
        "βλεννόρροια",
        "κόλλα",
        "τριγωνικό τεμάχιο",
        "φαράγγι",
        "γορίλλας",
        "αιματοβαμμένος",
        "κουτσομπολιό",
        "σκαρπέλο",
        "αρθρίτιδα",
        "κυβέρνηση",
        "αρπάζω",
        "αρπακτικός",
        "σχάρα",
        "τριμμένο",
        "κιγκλίδωμα",
        "τάφος",
        "απληστία",
        "άπληστος",
        "χειροβομβίδα",
        "πένθος",
        "παράπονο",
        "θλίβομαι",
        "λυπηρός",
        "βλοσυρός",
        "λέρα",
        "ρυπαρός",
        "άλεση",
        "τρομερός",
        "ψαρός",
        "βογγητό",
        "NO TRANSLATION",
        "ακαθάριστο",
        "αλλόκοτος",
        "γειωμένο",
        "αβάσιμος",
        "γκρινιάζω",
        "σφυρίζοντας",
        "μνησικακία",
        "δύστροπα",
        "φρικτός",
        "τραχύς",
        "γογγυσμός",
        "γκρινιάρης",
        "κλεφτοπόλεμος",
        "πονηριά",
        "καρμανιόλα",
        "ενοχή",
        "ένοχος",
        "πρόσχημα",
        "γλάρος",
        "εύπιστος",
        "όπλο",
        "έκχυση",
        "συνωμοσία",
        "αθίγγανος",
        "στρίγγλα",
        "καταβεβλημένος",
        "τριχωτός",
        "στα μέσα του δρόμου",
        "παραίσθηση",
        "καπίστρι",
        "να σταματήσει",
        "κάλαθος",
        "σακατεύω",
        "μειονέκτημα",
        "κρέμασμα",
        "δήμιος",
        "παρενοχλούν",
        "προάγγελος",
        "σκληρυνθεί",
        "σκληρότητα",
        "ταλαιπωρία",
        "πόρνη",
        "κανω κακο",
        "επιβλαβής",
        "τραγουδώντας",
        "βασανίζω",
        "τραχύτητα",
        "χασίσι",
        "χασίσι",
        "βιαστικός",
        "μισώ",
        "μισητός",
        "μίσος",
        "έχθρα",
        "αγέρωχος",
        "στέκι",
        "στοιχειωμένος",
        "πανωλεθρία",
        "κίνδυνος",
        "επικίνδυνος",
        "ομίχλη",
        "πονοκέφαλο",
        "μεθυστικός",
        "ακρόαση",
        "φήμη",
        "νεκροφόρα",
        "πόνος στην καρδιά",
        "καούρα",
        "άκαρδος",
        "αλλόθρησκος",
        "βαριά",
        "φτέρνα",
        "υψώ",
        "στυγερός",
        "κόλαση",
        "καταχθόνιος",
        "ανήμπορος",
        "ανικανότητα",
        "αιμορραγία",
        "αιμορροϊδές",
        "αίρεση",
        "αιρετικός",
        "ερμαφόδιτος",
        "ηρωίνη",
        "έρπης",
        "ιό έρπητα",
        "δισταγμός",
        "κεκρυμμένος",
        "βδελυρός",
        "εμποδίζοντας",
        "εμπόδιο",
        "hippie",
        "σφύριγμα",
        "συριγμός",
        "Κτύπημα",
        "μέχρι σήμερα",
        "κυψέλη",
        "βραχνός",
        "σεβάσμιος",
        "απάτη",
        "αλήτης",
        "γουρούνι",
        "κοίλος",
        "ολοκαύτωμα",
        "άστεγος",
        "νοσταλγία για το σπίτι",
        "ανθρωποκτόνος",
        "ανθρωποκτονία",
        "φιλομοφυλία",
        "κουκούλα",
        "αγκύλος",
        "σφύριγμα",
        "απελπισμένος",
        "απελπισία",
        "ορδή",
        "φρικτός",
        "τρομακτικά",
        "φρικαλέος",
        "φρικιαστικός",
        "τρομοκρατημένος",
        "φοβερός",
        "φρίκη",
        "φρίκη",
        "όμηρος",
        "εχθρικός",
        "εχθροπραξίες",
        "εχθρότητα",
        "ουρλιάζω",
        "ξεφυσάω",
        "απάτη",
        "εξευτελίζω",
        "ταπεινωτικό",
        "ταπείνωση",
        "διαίσθηση",
        "πεινασμένος",
        "κυνηγός",
        "κυνήγι",
        "τυφώνας",
        "βιαστικός",
        "πλήγμα",
        "βλαβερός",
        "πληγώνει",
        "καταφερτζής",
        "Ύδρα",
        "υδροκεφαλία",
        "δημοσιότητα",
        "υπερβολή",
        "υποκρισία",
        "υποκριτής",
        "υποκριτικός",
        "υστερία",
        "υστερικός",
        "ηλιθιότητα",
        "βλάκας",
        "βλακώδης",
        "τεμπέλης",
        "ειδωλολατρεία",
        "άγνοια",
        "αμαθής",
        "αγνοώ",
        "Εγώ θα",
        "παράνομος",
        "παρανομία",
        "δυσανάγνωστος",
        "νόθος",
        "παράνομος",
        "αγράμματος",
        "ασθένεια",
        "παράλογος",
        "ψευδαίσθηση",
        "μιμηθεί",
        "μίμηση",
        "ανώριμος",
        "άωρο",
        "ανήθικος",
        "ανηθικότητα",
        "χειροτερεύω",
        "βλάβη",
        "αδιάβατος",
        "ανυπομονησία",
        "ανυπόμονος",
        "κατηγορώ",
        "καταγγελία",
        "εμποδίζουν",
        "ατέλεια",
        "ατελή",
        "υποδύομαι",
        "μίμηση",
        "αδυσώπητος",
        "εμπλέκω",
        "αγενής",
        "επιβολή",
        "αδύνατο",
        "ανικανότητα",
        "ανίκανος",
        "εγκλείω",
        "ανεφάρμοστος",
        "φυλακίζω",
        "φυλακίστηκε",
        "φυλάκιση",
        "απρέπεια",
        "ασύνετος",
        "ακάθαρτος",
        "ακαθαρσία",
        "απόδοση",
        "αδυναμία",
        "απρόσιτος",
        "ανακριβής",
        "εν ΔΡΑΣΕΙ",
        "αδράνεια",
        "ανεπάρκεια",
        "ανεπαρκής",
        "απαράδεκτος",
        "ανόητος",
        "ανεφάρμοστος",
        "ακατάλληλος",
        "απροσεξία",
        "μη ακουστός",
        "ανυπολόγιστος",
        "ανικανότητα",
        "φυλάκιση",
        "σε περίπτωση",
        "εμπρηστικός",
        "θυμίαμα",
        "αδιάκοπος",
        "αιμομιξία",
        "αιμομικτικός",
        "αποτέφρωση",
        "ερεθίζω",
        "ανεπιεικής",
        "ασυνάρτητος",
        "ασύμβατες",
        "ανικανότητα",
        "ανίκανος",
        "ατέλεια",
        "ακατανόητος",
        "ανάρμοστος",
        "ασήμαντος",
        "απερίσκεπτος",
        "ασυνέπεια",
        "άβολος",
        "ανακριβής",
        "δύσπιστος",
        "ενοχοποίηση",
        "εφιάλτης",
        "υφίσταμαι",
        "ανίατος",
        "εισβολή",
        "απρεπής",
        "αναποφάσιστο",
        "αναποφάσιστος",
        "αδικαιολόγητος",
        "αποζημιώνω",
        "συμβόλαιο",
        "ακαθόριστος",
        "ενάγω",
        "κατηγορητήριο",
        "αδιαφορία",
        "άπορος",
        "αγανακτισμένος",
        "αγανάκτηση",
        "ασαφής",
        "κατήχηση",
        "νωχελικός",
        "ατελέσφορος",
        "άκαρπος",
        "ανεπάρκεια",
        "ανεπαρκής",
        "δεξιός",
        "απρέπεια",
        "ανισότητα",
        "άδικος",
        "αδρανής",
        "αδικαιολόγητος",
        "NO TRANSLATION",
        "άπειρος",
        "ανεξήγητος",
        "κακόφημος",
        "κακοφημία",
        "βρεφοκτονία",
        "νηπιακός",
        "στρατιώτης",
        "μολύνω",
        "μόλυνση",
        "μολυσματικός",
        "κατώτερος",
        "κατωτερότητα",
        "κόλαση",
        "αγονία",
        "ενόχληση",
        "άπιστος",
        "απιστία",
        "ασταθής",
        "αναπηρία",
        "φλεγμονή",
        "φουσκωμένο",
        "πληθωρισμός",
        "επιβάλλω",
        "επιβολή",
        "γρίπη",
        "πληροφορητής",
        "παράβαση",
        "σπάνια",
        "παράβαση",
        "αναστέλλω",
        "αφιλόξενος",
        "απάνθρωπος",
        "απανθρωπία",
        "εχθρικός",
        "ανομία",
        "διαταγή",
        "βλάπτω",
        "τραυματίας",
        "επιβλαβής",
        "βλάβη",
        "αδικία",
        "έγκλειστος",
        "αδρανής",
        "παράφρων",
        "παράνοια",
        "ανασφαλής",
        "ανασφάλεια",
        "ύπουλος",
        "ασημαντότητα",
        "ασήμαντος",
        "άνοστος",
        "αυθάδης",
        "αφερεγγυότητα",
        "αφερέγγυος",
        "αστάθεια",
        "ΗΘΙΚΟΣ ΑΥΤΟΥΡΓΟΣ",
        "υποκίνηση",
        "ανεπάρκεια",
        "ανεπαρκής",
        "ανεπαρκώς",
        "προσβολή",
        "προσβλητικός",
        "στασιαστής",
        "ανυπέρβλητος",
        "εξέγερση",
        "μεταξύ",
        "απαγόρευση",
        "παρέμβαση",
        "ενταφιασμός",
        "διακοπή",
        "διακόπηκε",
        "χωρίς διαθήκη",
        "εκφοβίζω",
        "εκφοβισμός",
        "ανυπόφορος",
        "μισαλλοδοξία",
        "μισαλλόδοξος",
        "μεθυσμένος",
        "ατίθασος",
        "μηχανοραφία",
        "παρείσακτος",
        "εισχώρηση",
        "παρεμβαίνων με αυθάδεια",
        "εισβαλλει",
        "επιδρομέας",
        "ακυρώ",
        "ακύρωση",
        "άκυρο",
        "εισβολή",
        "ακούσιος",
        "εμπλοκή",
        "ωργισμένος",
        "NO TRANSLATION",
        "σίδερα",
        "παράλογος",
        "παραλογισμός",
        "ασυμβίβαστος",
        "ακανόνιστος",
        "παρατυπία",
        "άσχετος",
        "ανεπανόρθωτος",
        "ανεύθυνος",
        "ασεβής",
        "αμετάκλητος",
        "ευερέθιστο",
        "ευερεθιστότητα",
        "ερεθιστικό",
        "ερεθισμός",
        "απομονωμένος",
        "απομόνωση",
        "κουβεντολόι",
        "φυλακή",
        "ακατάληπτη γλώσσα",
        "αταίριαστος",
        "ικτερός",
        "ζηλιάρης",
        "ζήλια",
        "διακινδυνεύω",
        "διακινδύνευση",
        "Γιάννης",
        "αστείο",
        "NO TRANSLATION",
        "μπέρδεμα",
        "σκουπίδι",
        "χούντα",
        "νεανικός",
        "kern",
        "λάκτισμα",
        "απαγωγή",
        "σκοτώνω",
        "φόνος",
        "χαρταετός",
        "πένθιμη κωδωνοκρουσία",
        "με κόμπους",
        "βαρύς",
        "κοπιώδης",
        "λαβύρινθος",
        "έλλειψη",
        "λείπει",
        "ανεπαρκής",
        "φορτωμένος",
        "καθυστέρηση",
        "μόνωση",
        "φωλιά",
        "θρήνος",
        "ολίσθηση έδαφους",
        "άτονος",
        "εξασθενώ",
        "αδύνατος",
        "μεσολάβηση",
        "κλοπή",
        "μαστίγιο",
        "αργά",
        "βραδύτης",
        "λανθάνων",
        "τουαλέτες",
        "γελοίος",
        "λάβα",
        "ανομία",
        "αγωγή",
        "δικηγόρος",
        "αμελής",
        "καθαρτικό",
        "τεμπέλης",
        "διαρροή",
        "διαρροή",
        "διαρρέων",
        "άδεια",
        "βδέλλα",
        "βδέλλες",
        "NO TRANSLATION",
        "λεμόνι",
        "λέπρα",
        "λεσβία",
        "ελαττώνω",
        "μικρότερος",
        "θανατηφόρος",
        "λήθαργος",
        "λευχαιμία",
        "είσπραξη",
        "έκφυλος",
        "σύνδεσμος",
        "ψεύτης",
        "λίββελος",
        "γλείψιμο",
        "ψέμα",
        "άψυχος",
        "περιωρισμένος",
        "χαλαρός",
        "στουπί",
        "υγρό",
        "αδιάφορος",
        "διάδικος",
        "έρχομαι εις δίκη",
        "δίκη",
        "φιλόδικος",
        "σκουπίδια",
        "πελιδνός",
        "φρατζόλα",
        "αργόσχολος",
        "NO TRANSLATION",
        "σιχαίνομαι",
        "σιχαμάρα",
        "απεχθής",
        "εργαζόμενος παρασκηνιακώς",
        "NO TRANSLATION",
        "ακρίδα",
        "υψηλός",
        "μοναξιά",
        "μοναχικός",
        "έρημος",
        "τουαλέτα",
        "αργαλειός",
        "loon",
        "ανισόρροπος",
        "λάφυρο",
        "χάνω",
        "χάνοντας",
        "απώλεια",
        "χαμένος",
        "ένταση",
        "σαλόνι",
        "ψείρα",
        "πιο χαμηλα",
        "πτώση",
        "χαμηλότερο",
        "πεδιάς",
        "ταπεινός",
        "γελοίος",
        "ξύλευση",
        "μάζα",
        "έχων εξογκώματα",
        "παραφροσύνη",
        "θεοπάλαβος",
        "δύσκολη θέση",
        "δέλεαρ",
        "μακάβριος",
        "ενεδρεύω",
        "δόλιος",
        "πλούσια βλάστηση",
        "λαγνεία",
        "λάγνος",
        "ξαπλωμένη",
        "θανατώ άνευ δίκης",
        "σκήπτρο",
        "τρελός",
        "τρελαίνομαι",
        "παραφρόντας",
        "παραφροσύνη",
        "μαφία",
        "ιδιοτροπία",
        "πρόχειρος",
        "ασθένεια",
        "δυσφορία",
        "ελονοσία",
        "κακόβουλος",
        "αδικοπραγία",
        "δυσμορφία",
        "κακία",
        "κακεντρεχής",
        "κακόβουλος",
        "μοχθηρία",
        "κακόηθες",
        "αδίκημα",
        "mandamus",
        "NO TRANSLATION",
        "μάγγανο",
        "μανία",
        "μανιακός",
        "μανιακός",
        "χειραγωγώ",
        "χειρισμός",
        "ανθρωποκτονία",
        "κοπριά",
        "παραμορφώνω",
        "περιθώριο",
        "μαρόν",
        "λουρί ίππου",
        "μάρτυρας",
        "μαρτύριο",
        "μαζοχισμός",
        "σφαγή",
        "υλισμός",
        "υλιστής",
        "μελανιού",
        "χωρίς νόημα",
        "ιλαρά",
        "ανακατεύομαι",
        "μέτριος",
        "μετριότητα",
        "μελαγχολικός",
        "μελαγχολία",
        "melee",
        "μελόδραμα",
        "τήξη",
        "απειλή",
        "απειλητικός",
        "ταπεινός",
        "μισθοφόρος",
        "ανηλεής",
        "Ανω ΚΑΤΩ",
        "ακατάστατος",
        "μετάσταση",
        "μεθανόλης",
        "μούχλα",
        "πολιτοφυλακή",
        "διακωμώδηση",
        "σμικροποιώ",
        "ελάχιστο",
        "μειονότητα",
        "NO TRANSLATION",
        "κακή διαγωγή",
        "αποτυχία",
        "κακό",
        "άτακτος",
        "παρανόηση",
        "κακή συμπεριφορά",
        "άθλιος",
        "άθλιως",
        "μιζέρια",
        "ατυχία",
        "εσφαλμένος",
        "ατύχημα",
        "κακή ερμηνεία",
        "παρασύρω",
        "αποπλανητικός",
        "κακή διαχείριση",
        "αναντιστοιχία",
        "εσφαλμένο όνομα",
        "βάζω κατά λάθος",
        "άσχημη",
        "διαστρεβλώνω",
        "διαστρέβλωση",
        "παρερμηνεύονται",
        "λείπει",
        "εσφαλμένη έκθεση",
        "λάθος",
        "εσφαλμένος",
        "ερωμένη",
        "NO TRANSLATION",
        "παρεξηγώ",
        "παρεξήγηση",
        "κακή χρήση",
        "οβολός",
        "όχλος",
        "κοροϊδία",
        "διακωμώδηση",
        "παρενόχληση",
        "μονόχρωμος",
        "μονοπωλιστής",
        "μουσώνας",
        "Τέρας",
        "τερατούργημα",
        "κακόκεφος",
        "συζητήσιμος",
        "νοσηρός",
        "νοσηρότητα",
        "νεκροτομείο",
        "ετοιμοθάνατος",
        "βλάκας",
        "βλακώδης",
        "κομματάκι",
        "θνητός",
        "θνησιμότητα",
        "ταπείνωση",
        "νεκροτομείο",
        "κουνούπι",
        "θρηνώ",
        "λυπηρός",
        "πένθος",
        "βόρβορος",
        "λάσπη",
        "συγχύζομαι",
        "μπερδεμένα",
        "λασπωμένος",
        "μανσόν",
        "μουλάρι",
        "μαμά",
        "ψέλλισμα",
        "παρωτίτιδα",
        "δολοφονία",
        "δολοφόνος",
        "φονικό",
        "σκοτεινός",
        "NO TRANSLATION",
        "μπαγιάτικος",
        "μεταλλαγμένος",
        "ακρωτηριασμένο",
        "ακρωτηριασμός",
        "ανταρσία",
        "NO TRANSLATION",
        "ρύγχος",
        "μυωπία",
        "συλλαμβάνω",
        "ναδίρ",
        "NO TRANSLATION",
        "αφελής",
        "ανώνυμος",
        "χνουδωτός",
        "ναρκωτικό",
        "δυσάρεστος",
        "άτακτος",
        "ναυτία",
        "αηδιαστικός",
        "NO TRANSLATION",
        "ενδεής",
        "ενδεής",
        "άνομος",
        "άρνηση",
        "αρνητικός",
        "παραμέληση",
        "αφρόντιστος",
        "παραμέληση",
        "αμέλεια",
        "αμελής",
        "NO TRANSLATION",
        "Νέγρος",
        "νεποτισμός",
        "νευρικός",
        "κάτω",
        "τσουκνίδα",
        "νευραλγία",
        "νεύρωση",
        "νευρωτικός",
        "νικοτίνη",
        "αράπης",
        "εφιάλτης",
        "μηδενισμός",
        "θόρυβος",
        "θορυβώδης",
        "NO TRANSLATION",
        "ανοησίες",
        "ανόητος",
        "θηλιά",
        "ανυπαρξία",
        "επιβλαβής",
        "ενόχληση",
        "NO TRANSLATION",
        "ακυρώ",
        "μουδιασμένος",
        "μούδιασμα",
        "NO TRANSLATION",
        "βλάκας",
        "παχύσαρκος",
        "ευσαρκία",
        "μαγεία",
        "obit",
        "νεκρολογία",
        "ένσταση",
        "απαράδεκτος",
        "υποχρεώνω",
        "οφειλέτη",
        "σβήνω",
        "καταστραφεί",
        "εξάλειψη",
        "λήθη",
        "απεχθής",
        "άσεμνος",
        "αισχρότητα",
        "αφάνεια",
        "εμπόδιο",
        "πεισματάρης",
        "κωλυσιεργώ",
        "παρεμπόδιση",
        "κωλυσιεργικός",
        "κουτός",
        "μυστηριώδης",
        "μοναδικότητα",
        "απεχθής",
        "οσμή",
        "προσβάλλω",
        "προσβληθεί",
        "παραβάτης",
        "αδίκημα",
        "προσβλητικός",
        "αυτοσχέδιος",
        "πέλαγος",
        "δράκοντας",
        "οσφρητικός",
        "ολιγαρχία",
        "οιωνός",
        "δυσοίωνος",
        "παραλείπω",
        "βαρύς",
        "βάρος",
        "λάσπη",
        "αδιαφανής",
        "μελοδραματικός",
        "ναρκωτικός",
        "δογματικός",
        "όπιο",
        "αντίπαλος",
        "εναντιώνομαι",
        "αντίθετος",
        "αντιπολίτευση",
        "καταπιέζω",
        "καταπίεση",
        "καταθλιπτικός",
        "καταπιεστής",
        "orc",
        "δοκιμασία",
        "πυροβολικό",
        "ορφανό",
        "φαινομενικά",
        "εκβάλλω",
        "απόβλητος",
        "κατακραυγή",
        "αποχωρητήριο",
        "παράξενος",
        "εκτός νόμου",
        "προσβολή",
        "πανηγυρική υποδοχή",
        "καταθλιπτικός",
        "παραφορτώνω",
        "νεφελώδης",
        "παρακάνω",
        "υπερβολική δόση",
        "εκπρόθεσμος",
        "υπερεκτίμησε",
        "ξεχείλισμα",
        "κατάφυτος",
        "παραφορτώνω",
        "υπερπληρωθεί",
        "καταβάλλω",
        "συντριπτικός",
        "υπερτιμημένο",
        "επίβλεψη",
        "ανατροπή",
        "ανατροπή",
        "κατακλύζω",
        "συγκλονισμένοι",
        "οφειλόμενος",
        "οξείδωση",
        "πόνος",
        "πικραμένος",
        "επώδυνος",
        "οδυνηρά",
        "κόποι",
        "παράλυση",
        "πανδημία ιατρική",
        "NO TRANSLATION",
        "πανικός",
        "παράλυση",
        "παράλυση",
        "παράνοια",
        "παράσιτο",
        "NO TRANSLATION",
        "παπαγάλος",
        "φειδωλός",
        "οπαδός",
        "NO TRANSLATION",
        "παθητικός",
        "παθητικότητα",
        "κηλίδα",
        "αξιολύπητο",
        "προστατευτικός",
        "NO TRANSLATION",
        "σπάνις",
        "άπορος",
        "πιόνι",
        "αποπληρωμή",
        "πληρωμή",
        "ιδιαιτερότητες",
        "πεζός",
        "ποινικός",
        "ποινή",
        "διείσδυση",
        "αναμορφωτήριο",
        "απώλεια",
        "κίνδυνος",
        "επικίνδυνος",
        "χάνομαι",
        "φθαρτός",
        "έχασαν τη ζωή τους",
        "πεθαίνουν",
        "ψευδορκία",
        "ολέθριος",
        "δράστης",
        "διαιώνιση",
        "αμηχανών",
        "αμηχανία",
        "καταδιώκω",
        "καταδίωξη",
        "διατάραξη",
        "κοκκίτης",
        "διεστραμμένος",
        "διαστροφή",
        "διαστρεβλώ",
        "διεστραμμένος",
        "απαισιοδοξία",
        "απαισιόδοξος",
        "λοιμός",
        "λοιμός",
        "κατοικίδιο ζώο",
        "μικροπρεπής",
        "φάντασμα",
        "φλέγμα",
        "ψευδής",
        "φρουρώ",
        "φρουρά απεργίας",
        "πίκλα",
        "Χοίρος",
        "περιστέρι",
        "αιμορροϊδές",
        "λεηλασία",
        "ρουφιάνος",
        "σπυρί",
        "πεύκο",
        "μικρός οδοντωτός τροχός",
        "πικάρω",
        "πειρατεία",
        "πειρατής",
        "πιστόλι",
        "παγίδα",
        "λογοκλοπή",
        "πανούκλα",
        "ενάγων",
        "επιστρωμένο",
        "παίχτης",
        "έκκληση",
        "κατάσταση",
        "βραδύ βάδισμα",
        "βολίδα",
        "λεηλασία",
        "βουτιά",
        "πνευμονία",
        "λαθροθηρία",
        "άσκοπος",
        "δηλητήριο",
        "δηλητηρίαση",
        "δηλητηρίαση",
        "δηλητηριώδης",
        "σακί",
        "πολεμική",
        "πολιομυελίτις",
        "ρυπαίνω",
        "ρύπανση",
        "πολυγαμία",
        "λαμπρότητα",
        "πομπώδης",
        "βαρύς",
        "πτωχώς",
        "κρότος",
        "ακανθόχοιρος",
        "πορνογραφία",
        "πορνογραφία",
        "πορνογραφικός",
        "πορνογραφία",
        "στάση",
        "κατεχόμενος",
        "κατοχή",
        "μεταθανάτιος",
        "αναβολή",
        "λίβρα",
        "φτώχεια",
        "ανίσχυρος",
        "φάρσα",
        "αβέβαιος",
        "περίβολος",
        "αρπακτικός",
        "δύσκολη θέση",
        "εγκυμοσύνη",
        "προκατάληψη",
        "προκατειλημμένος",
        "επιζήμιος",
        "προμελετημένη",
        "πίεση",
        "αλαζονικός",
        "προσποιούμαι",
        "προσποιητός",
        "προσποιώντας",
        "προσποίηση",
        "προθέσεις",
        "προληπτικός",
        "λεία",
        "πούτσος",
        "ακανθώδης",
        "φυλακή",
        "φυλακισμένος",
        "μυστικός",
        "πρόβλημα",
        "χρονοτριβώ",
        "αναβλητικότητα",
        "βέβηλος",
        "βλασφημία",
        "αφθονία",
        "απαγορευμένος",
        "απαγόρευση",
        "παρατείνω",
        "σύμμικτος",
        "προπαγάνδα",
        "καταδιώκω",
        "δίωξη",
        "πόρνη",
        "πορνεία",
        "πρόκληση",
        "προκλητικός",
        "εξετάζω",
        "μόχλευση",
        "ψύχωση",
        "δημοσιολόγος",
        "φουσκωμένος",
        "γροθιά",
        "πικάντικος",
        "βαζω τιμωρια",
        "τιμωρούνται",
        "τιμωρία",
        "τιμωρία",
        "τιμωρητικός",
        "καθαρτήριο",
        "καθαρίζω",
        "πύο",
        "κομπογιαννίτης",
        "έλος",
        "ορτύκι",
        "δίλημμα",
        "φιλονικία",
        "ακυρώ",
        "καταβάλλω",
        "αμφισβητήσιμος",
        "υδράργυρος",
        "εγκαταλείπω",
        "ανατριχίλα",
        "τρεμάμενος",
        "κουίζ",
        "όχλος",
        "φανατικός",
        "λύσσα",
        "ράφι",
        "ρακέτα",
        "ακτινοβολία",
        "ραδιενεργός",
        "ραδόνιο",
        "οργή",
        "οργισμένος",
        "κουρέλια",
        "επιδρομή",
        "ράγα",
        "έμβολο",
        "απλωμένος",
        "τρέχω",
        "ταγγός",
        "λύτρα",
        "βιασμός",
        "αρπακτικών",
        "κατεργάρης",
        "εξάνθημα",
        "αρουραίος",
        "εκτίμηση",
        "τραχύς",
        "πεινασμένος",
        "έξαλλος",
        "αντιδραστικός",
        "όπισθεν",
        "επαναστάτης",
        "επίπληξη",
        "αντικρούω",
        "δύστροπος",
        "ύφεση",
        "υποτροπή",
        "ριψοκίνδυνος",
        "απερισκεψία",
        "περιττός",
        "άμπωτη",
        "πυρίμαχος",
        "άρνηση",
        "αρνηθεί",
        "αρνήθηκε",
        "οπισθοχώρηση",
        "οπισθοδρόμηση",
        "μετανιώνω",
        "λυπηρός",
        "λυπημένος",
        "λυπούμαι",
        "κανονιστική ρύθμιση",
        "ηνίο",
        "απορρίπτω",
        "απορρίφθηκε",
        "απόρριψη",
        "απορρίπτει",
        "υποτροπή",
        "υποβιβασμός",
        "παραιτούμαι",
        "απρόθυμος",
        "επανάπεμψη",
        "θεραπευτικός",
        "αμελής",
        "τύψη συνειδήσεως",
        "μετακίνηση",
        "αφαιρώ",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "αποστάτης",
        "απαρνιέμαι",
        "αποκήρυξη",
        "NO TRANSLATION",
        "αποκρουστικός",
        "απωθώντας",
        "καταστέλλω",
        "καταστολή",
        "αυστηρά επίπληξη",
        "ανατύπωση",
        "αντεκδίκηση",
        "όνειδος",
        "Δημοκρατία",
        "αποκήρυξη",
        "αποστροφή",
        "ακυρώ",
        "ακύρωση",
        "φέρω βαρέως",
        "μνησίκακος",
        "μνησικακία",
        "παραιτούμαι",
        "παραίτηση",
        "καρτερικός",
        "αντιστέκομαι",
        "αντίσταση",
        "ανθεκτικός",
        "αντιστέκονται",
        "αναχαιτίζω",
        "περιορίζω",
        "περιορισμός",
        "περιοριστικός",
        "ανταποδίδω",
        "αντίποινα",
        "αντιπολιτευτικό",
        "επιβραδύνω",
        "καθυστέρηση",
        "εχέμυθος",
        "ανταπαντώ",
        "ανακαλώ",
        "ανάκληση",
        "περισυλλογή",
        "τιμωρία",
        "παλινδρομικός",
        "εκδίκηση",
        "αντιστροφή",
        "ανάκληση",
        "ανακαλώ",
        "επανάσταση",
        "αποκρουστικός",
        "περίστροφο",
        "μεταστροφή",
        "ρευματισμός",
        "ξεχαρβαλωμένος",
        "διατρυπημένο",
        "γελοιοποίηση",
        "γελοίος",
        "διαδεδομένος",
        "τουφέκι",
        "ρήγμα",
        "άκαμπτος",
        "ακαμψία",
        "αυστηρότητα",
        "αυστηρός",
        "κλοιός",
        "ταραχή",
        "ταραχώδης",
        "κίνδυνος",
        "επικίνδυνος",
        "ανταγωνισμός",
        "ληστεύω",
        "ληστής",
        "ληστεία",
        "κατεργάρης",
        "κορώνη",
        "σαπίλα",
        "σάπισμα",
        "τραχύτητα",
        "NO TRANSLATION",
        "σειρά",
        "εριστικός",
        "σκουπίδια",
        "χαλίκια",
        "μετανιώνω",
        "σούφρα",
        "τραχύς",
        "καταστροφή",
        "ξεπεσμένος",
        "ολέθριος",
        "φήμη",
        "δραπέτης",
        "ρήξη",
        "NO TRANSLATION",
        "σκουριά",
        "σκουριασμένος",
        "αδίστακτος",
        "NO TRANSLATION",
        "σαμποτάζ",
        "θυσίες",
        "δυστυχώς",
        "θλίψη",
        "γέρνω",
        "χυμός δέντρου",
        "σαρκασμός",
        "σάρκωμα",
        "σαρδόνιος",
        "σατανικός",
        "κορεσμένο",
        "άγριος",
        "αγριότητα",
        "ψώρα",
        "ικρίωμα",
        "χειρουργικό νυστέρι",
        "φολιδωτός",
        "σκάνδαλο",
        "σκανδαλώδης",
        "ανεπαρκής",
        "αποδιοπομπαίος τράγος",
        "ουλή",
        "σπάνιος",
        "μόλις",
        "έλλειψη",
        "φόβος",
        "οδοκαθαριστής",
        "σχέδιο",
        "σχίσμα",
        "σχιζοφρένεια",
        "ισχιαλγία",
        "χλεύη",
        "μαλώνω",
        "κατσάδα",
        "καψάλισμα",
        "περιφρόνηση",
        "σκορπιός",
        "scotch",
        "αχρείος",
        "μάστιγα",
        "περιπλάνηση",
        "τρομώδης νόσος",
        "κραυγή",
        "σκούξιμο",
        "στριγκλιά",
        "βιδωμένο",
        "ταραχή",
        "σφουγγάρισμα",
        "διερευνώ",
        "λεπτομερής έλεγχος",
        "απόβρασμα",
        "καίω",
        "απόσχιση",
        "απομονωμένος",
        "NO TRANSLATION",
        "έκκριση",
        "εκκριτικός",
        "αιρετικός",
        "στάση",
        "αποπλανώ",
        "αποπλάνηση",
        "διαχωρίζω",
        "διαχωρίζονται",
        "αρπάζω",
        "εγωιστικός",
        "ιδιοτέλεια",
        "γεροντικός",
        "αναίσθητος",
        "πρόταση",
        "σχισματικός",
        "σήψη",
        "σηπτικός",
        "κατάσχεση",
        "γαλήνιος",
        "φίδι",
        "υπηρέτης",
        "σερβίρισμα",
        "δουλοπρεπής",
        "σκλαβιά",
        "οπισθοδρόμηση",
        "κόβω",
        "απόβλητα",
        "δίκτυο αποχέτευσης",
        "παλιός",
        "καλύβα",
        "δεσμεύω",
        "σκιερός",
        "κλονισμός",
        "επισφαλής",
        "απάτη",
        "σφαγείο",
        "ντροπή",
        "επαίσχυντος",
        "αναίσχυντος",
        "Σαγκάη",
        "καρχαρίας",
        "θρυμματίζω",
        "καταστρέφονται",
        "υπόστεγο",
        "κέλυφος",
        "ράφια",
        "ναυάγιο",
        "σκατά",
        "ρίγος",
        "σοκ",
        "πλαστός",
        "βλαστός",
        "κυνήγι",
        "κλεψιά από κατάστημα",
        "έλλειψη",
        "έλλειψη",
        "βολή",
        "σπρώχνω",
        "επιδεικτικός",
        "σκούζω",
        "διαπεραστικός",
        "μαζεύω",
        "ζαρωμένος",
        "ανατριχιάζω",
        "αποφεύγω",
        "άρρωστος",
        "αηδής",
        "ασθενικός",
        "ασθένεια",
        "ανόητος",
        "NO TRANSLATION",
        "αμαρτωλός",
        "απαίσιος",
        "αμαρτωλός",
        "αμαρτία",
        "σειρήνα",
        "αδελφούλα",
        "δύσπιστος",
        "ατελής",
        "λοξή",
        "ολισθαίνω",
        "παραλείπω",
        "αψιμαχία",
        "χαλαρότητα",
        "σκωρία",
        "χτύπημα",
        "συκοφαντία",
        "συκοφαντικός",
        "σφαλιάρα",
        "σφαγή",
        "σφαγείο",
        "σφαγή",
        "δούλος",
        "σκλαβιά",
        "σκοτώνω",
        "φονιάς",
        "χιονόνερο",
        "γλοιώδης",
        "δραπετεύω",
        "γλιστράω",
        "NO TRANSLATION",
        "τσαπατσούλης",
        "νωθρότητα",
        "αδέξιος",
        "κέλυφος",
        "βραδύτης",
        "λάσπη",
        "γυμνοσάλιαγκας",
        "βραδύς",
        "πτωχογειτονιά",
        "κατάπτωση",
        "μομφή",
        "λίπος",
        "πόρνη",
        "πονηρός",
        "σκαμπίλι",
        "μικρό",
        "σπάσιμο",
        "έσπασαν",
        "πασάλειμμα",
        "μυρωδιά",
        "οσφραντικός",
        "χαζό χαμόγελο",
        "χτυπώ",
        "καπνιστής",
        "πνίγω",
        "μουτζούρα",
        "αυτάρεσκος",
        "εισάγω λαθρέως",
        "λαθρέμπορος",
        "λαθρεμπόριο",
        "καπνιά",
        "απροσδόκητο εμπόδιο",
        "παγίδες",
        "φίδι",
        "παγίδα",
        "γρύλισμα",
        "γκρινιάρης",
        "έρπω",
        "κρυφός",
        "χλεύη",
        "φτάρνισμα",
        "υπαινικτικός",
        "σνομπ",
        "μουλιάζω",
        "NO TRANSLATION",
        "σοσιαλιστής",
        "έδαφος",
        "λερωμένος",
        "σωματικός",
        "λύτης",
        "αιθάλη",
        "μαγεία",
        "ρυπαρός",
        "πληγή",
        "οδυνηρώς",
        "πόνος",
        "λύπη",
        "θλιμμένος",
        "NO TRANSLATION",
        "άψυχος",
        "αδελφή ψυχή",
        "θυμώνω",
        "δέρνω",
        "σπασμός",
        "γκέτα",
        "δόρυ",
        "κηλίδα",
        "φάντασμα",
        "φασματικός",
        "κερδοσκοπία",
        "ξόδεψε",
        "γεροντοκόρη",
        "πείσμα",
        "μοχθηρός",
        "σκλήθρα",
        "διαίρεση",
        "δυνατός",
        "λεία",
        "φθείρων",
        "ακτίνα",
        "σφουγγάρι",
        "φάντασμα",
        "εξάρθρωση",
        "γλέντι",
        "ξωτικό",
        "πλαστός",
        "καταιγίδα",
        "καταπατητής",
        "τάση προς εμετό",
        "συντρίβω",
        "ανησυχώ",
        "μαχαιριά",
        "τρίκλισμα",
        "στάσιμος",
        "λεκές",
        "μπαγιάτικος",
        "κοτσάνι",
        "απόσβεση",
        "στάση",
        "χτυπητός",
        "εντελώς",
        "ξάφνιασμα",
        "πείνα",
        "πεινασμένοι",
        "λιμοκτονούν",
        "ακίνητος",
        "βαρελοσανίδα",
        "κλέβω",
        "κλοπή",
        "κρύφιος",
        "στερεοτυπία",
        "στερεότυπος",
        "στείρος",
        "στειρότητα",
        "αυστηρός",
        "δύσκαμπτος",
        "ακαμψία",
        "πνίγω",
        "καταπνίγησαν",
        "στίγμα",
        "θνητό",
        "τσίμπημα",
        "δηκτικός",
        "τσιγκούνης",
        "βρώμα",
        "απαίσιος",
        "όριο",
        "αποθέματα",
        "κλαπεί",
        "πέτρα",
        "φτιαγμένος",
        "κόπρανα",
        "παύση",
        "καταιγίδα",
        "θυελλώδης",
        "τεταμένος",
        "στενά",
        "απομεμονωμένος",
        "ξένος",
        "στραγγαλίζω",
        "περιπλανώμενος",
        "στρες",
        "διαμάχη",
        "απεργία",
        "λωρίδα",
        "ταινία",
        "γυμνός",
        "κτύπημα",
        "πάλη",
        "αλαζονικό",
        "αποπληκτικός",
        "παραπάτημα",
        "εμβρόντητος",
        "ασταθής",
        "χαζος",
        "βλακεία",
        "νάρκη",
        "χοιροστάσιο",
        "υποτάσσω",
        "θέμα",
        "υποβληθεί",
        "υποταγή",
        "υποδούλωση",
        "υφιστάμενος",
        "κλήτευση",
        "υποχώρηση",
        "επιδότηση",
        "υπάρχω",
        "αφαιρώ",
        "ανατροπή",
        "ανατρεπτικός",
        "ανατρέπω",
        "υποκύπτω",
        "ρουφώ",
        "κορόιδο",
        "κανω μηνυση",
        "υποφέρω",
        "υποφέρων",
        "ταλαιπωρία",
        "αποπνικτικός",
        "ασφυξία",
        "αυτοκτονικός",
        "αυτοκτονία",
        "αγέλαστος",
        "κλήση",
        "βυθίστηκε",
        "επιπόλαιος",
        "περιττός",
        "προληπτικός",
        "καταστέλλω",
        "κατάπνιξη",
        "προσαύξηση",
        "κατσούφης",
        "παράδοση",
        "παραίτηση",
        "ευαίσθητος",
        "ύποπτος",
        "εναιώρημα",
        "υποψία",
        "ύποπτος",
        "μάκτρο",
        "τέλμα",
        "βαλτώδης",
        "σβάστικα",
        "πρήξιμο",
        "καταρροφώ",
        "χοίρος",
        "πρησμένος",
        "σύμπτωμα",
        "συγκοπή",
        "ταμπού",
        "κηλίδα",
        "NO TRANSLATION",
        "Μπλεγμένος",
        "βραδύτητα",
        "βραδυκίνητος",
        "δασμολόγιο",
        "θαμπώνω",
        "παραμένω",
        "άγευστος",
        "χλευασμός",
        "φόρος",
        "πειράζω",
        "πειράζω",
        "ανιαρός",
        "NO TRANSLATION",
        "θύελλα",
        "πειρασμός",
        "φτηνό σπίτι",
        "τερματικό",
        "λήξη",
        "τερμίτης",
        "τρομερός",
        "τρόμος",
        "τρομοκρατία",
        "τρομοκράτης",
        "τρομοκρατώ",
        "τέτανος",
        "τριχιά",
        "κλοπή",
        "θεϊσμός",
        "θεοκρατικός",
        "κλέφτης",
        "διψασμένος",
        "αγκάθι",
        "αγκαθωτός",
        "επιπόλαιος",
        "κοπανίζω",
        "απειλή",
        "απειλώ",
        "απειλητικές",
        "αλωνίζω",
        "παλμός",
        "γκάζι",
        "φονεύς",
        "γροθιά",
        "βροντή",
        "εγκάρσιος",
        "μικρή φιλονικία",
        "συνεσταλμένος",
        "δειλία",
        "ζαλισμένος",
        "υβρεολόγιο",
        "κουρασμένος",
        "κούραση",
        "κουραστικός",
        "χτύπημα",
        "φρύνος",
        "καπνός",
        "τουαλέτα",
        "πλεκτάνη",
        "ανέχομαι",
        "πονόδοντος",
        "βασανιστήριο",
        "σχισμένο",
        "τορπίλλη",
        "καυστικός",
        "αδίκημα",
        "επιθετική",
        "βασανιστήριο",
        "συγκενημένος",
        "ευαίσθητος",
        "σκληρός",
        "τοξικός",
        "τοξίνη",
        "τραγωδία",
        "τραγικός",
        "προδότης",
        "αλήτης",
        "έκσταση",
        "παράβαση",
        "στολίδια",
        "παγίδες",
        "Σκουπίδια",
        "άχρηστος",
        "τραυματικός",
        "NO TRANSLATION",
        "παρωδία",
        "επίβουλος",
        "προδοσία",
        "προδοσία",
        "τρόμος",
        "τρόμος",
        "τρόμος",
        "παράπτωμα",
        "δοκιμασία",
        "δικαστήριο",
        "τέχνασμα",
        "απάτη",
        "σαχλαμάρα",
        "ανάλαφρος",
        "γίγας",
        "ενοχλητικός",
        "τρομπέτα",
        "κατρακύλισμα",
        "όγκος",
        "όγκος",
        "θόρυβος",
        "ταραχώδης",
        "ταραχή",
        "ταραχώδης",
        "αναταραχή",
        "τράβηγμα",
        "τυφώνας",
        "τυραννικός",
        "τυραννία",
        "τύραννος",
        "ασχημία",
        "άσχημος",
        "έλκος",
        "απώτερος",
        "τελεσίγραφο",
        "ανίκανος",
        "Απαράδεκτος",
        "ανεξήγητος",
        "ανέγκριτος",
        "ασύνδετος",
        "ανέφικτος",
        "μη ελκυστικος",
        "ανεξουσιοδότητος",
        "αναπόφευκτος",
        "απληροφόρητος",
        "ανυπόφορος",
        "απιστία",
        "απίστευτος",
        "αγέννητος",
        "μυστηριώδης",
        "απολαυστικό",
        "αβέβαιος",
        "αμετάβλητος",
        "ακάθαρτος",
        "άβολος",
        "ασυνείδητος",
        "αναίσθητος",
        "αντισυνταγματικός",
        "αχαλίνωτος",
        "ανεξέλεγκτος",
        "αναποφάσιστος",
        "υπονομεύεται",
        "ανεπαρκώς αμειβόμενος",
        "κάτω του κανονικού μέγεθους",
        "ανεπιθύμητος",
        "ανεπιθύμητος",
        "ξεκάνω",
        "ανησυχία",
        "ανήσυχος",
        "αμόρφωτος",
        "άνεργος",
        "άνισος",
        "άνισος",
        "ανεξήγητο",
        "άδικος",
        "άδικο",
        "άπιστος",
        "δυσμενής",
        "ημιτελής",
        "ανελέητος",
        "ατυχής",
        "δυσμενής",
        "ανεκπλήρωτος",
        "χωρίς έπιπλα",
        "ασεβής",
        "αχάριστος",
        "δυστυχία",
        "δυστυχής",
        "ανθυγιεινός",
        "ανίερος",
        "ανευ σημασιας",
        "χωρίς εντύπωση",
        "αβελτίωτος",
        "απληροφόρητος",
        "αμύητος",
        "μη εμπνευσθείς",
        "ακατάληπτος",
        "ακούσια",
        "αδιάφορος",
        "πληκτικός",
        "άδικος",
        "αδικαιολόγητος",
        "αναιτιολόγητος",
        "αφιλοφρών",
        "άγνωστος",
        "παράνομος",
        "μη έχων άδειαν",
        "άτυχος",
        "ανοικονόμητος",
        "αφύσικος",
        "ανεπίσημος",
        "απλήρωτος",
        "δυσάρεστος",
        "μη δημοφιλής",
        "απρόβλεπτος",
        "απροετοίμαστος",
        "μη παραγωγικός",
        "ασύμφορος",
        "απροστάτευτος",
        "αδημοσίευτος",
        "αναξιόπιστος",
        "χωρίς ανταπόδοση",
        "άτακτος",
        "επισφαλής",
        "μη ικανοποιητικός",
        "ανικανοποίητος",
        "ανούσιος",
        "ασυνείδητος",
        "άστατος",
        "άσχημος",
        "αθωώς",
        "ανείπωτος",
        "ασταθής",
        "ανεπιτυχής",
        "ακατάλληλος",
        "άψαλτος",
        "ανυποστήρικτος",
        "μη βιώσιμη",
        "άπονος",
        "ατίθασος",
        "αστήρικτος",
        "αδιανόητος",
        "ακατάστατος",
        "πρόωρος",
        "Χωρίς τίτλο",
        "ανομολόγητος",
        "ανάγωγος",
        "αγύμναστος",
        "αναληθής",
        "αναξιόπιστος",
        "ανεγγύητος",
        "άπλυτος",
        "ανεπιθύμητος",
        "αδιάθετος",
        "απροθυμία",
        "ασύνετος",
        "χωρίς επίγνωση",
        "ανάξιος",
        "ανένδοτος",
        "αναστάτωση",
        "εξέγερση",
        "θόρυβος",
        "αναστατωμένος",
        "σκανταλιάρικο παιδί",
        "επείγων",
        "άχρηστος",
        "σφετερίζομαι",
        "σφετεριστεί",
        "τοκογλυφία",
        "κενή θέση",
        "κενός",
        "ασαφής",
        "ασάφεια",
        "μάταια",
        "βρυκόλακας",
        "εξαφανίστηκε",
        "ματαιοδοξία",
        "ανεμοβλογιά",
        "κιρσώδης",
        "βλαστικός",
        "σφοδρός",
        "βεντέττα",
        "εκδίκηση",
        "εκδικητικός",
        "δηλητήριο",
        "δηλητηριώδης",
        "πολυλογία",
        "χείλος",
        "ζωύφια",
        "εναντίον",
        "ίλιγγος",
        "βέτο",
        "μέγγενη",
        "φαύλος",
        "θύμα",
        "θύματα",
        "παληάνθρωπος",
        "άθλιος",
        "εκδικητικός",
        "παράβαση",
        "βία",
        "βίαιος",
        "βιαίως",
        "οχιά",
        "τοξικότητα",
        "ιός",
        "επίσκεψη",
        "στρίγγλα",
        "μεταβλητότητα",
        "ηφαίστειο",
        "εμετό",
        "βουντού",
        "χυδαίος",
        "χυδαιότητα",
        "τρωτό",
        "όρνιο",
        "φλυαρώ",
        "κλαίω",
        "Περιμένετε",
        "κυλιέμαι στη λάσπη",
        "NO TRANSLATION",
        "παρακμή",
        "στερούμενος",
        "πόλεμος",
        "φύλακας",
        "προϊόντα",
        "πόλεμος",
        "πολεμοχαρής",
        "προειδοποιώ",
        "στημόνι",
        "στραβωμένος",
        "κρεατοελλιά",
        "απόβλητα",
        "αποτυχημένος",
        "σπάταλος",
        "φθείρων",
        "υδαρής",
        "αμφιταλαντεύομαι",
        "αποδυναμωθεί",
        "ασθενώς",
        "αδυναμία",
        "φορούν",
        "κουρασμένα",
        "κούραση",
        "κουρασμένος",
        "πένθιμα ενδύματα χήρας",
        "κλαίω",
        "Περίεργο",
        "φρικιό",
        "NO TRANSLATION",
        "υπηρέτρια",
        "ηχηρό κτύπημα",
        "ιδιοτροπία",
        "κλαψούρισμα",
        "μαστίγιο",
        "ανεμοστρόβιλος",
        "ουίσκι",
        "πόρνη",
        "κακός",
        "κακία",
        "άγριος",
        "αγριόγατα",
        "υγρό πύρ",
        "σκόπιμος",
        "wimp",
        "wimpy",
        "ταράσσομαι",
        "μάγισσα",
        "μαγεία",
        "αποσύρω",
        "μαραίνω",
        "μαραμένα",
        "αλίμονο",
        "αξιολύπητος",
        "θλιβερά",
        "λόγια",
        "σκουλήκι",
        "φθαρμένο",
        "ανήσυχος",
        "ανησυχία",
        "ανησυχητικό",
        "χειρότερος",
        "επιδείνωση",
        "άνευ αξίας",
        "πληγή",
        "διαμάχη",
        "Οργή",
        "επιβάλλω",
        "ναυάγιο",
        "σαραβαλιασμένος",
        "γαλλικο ΚΛΕΙΔΙ",
        "πάλη",
        "φουκαράς",
        "άθλιος",
        "λανθασμένος",
        "αδικοπραγία",
        "άδικος",
        "εσφαλμένα",
        "κατειργασμένος",
        "στραβός",
        "ξενοφοβία",
        "χασμουρητό",
        "χασμουρητό",
        "κραυγή",
        "χρύση των ζώων",
        "ούρλιασμα",
        "φερμουάρ",
    ]
)

_ambivalent = set(
    [
        "αφθονία",
        "ένοπλος",
        "βάλσαμο",
        "καύχημα",
        "θορυβώδης",
        "βιβλιοφάγος",
        "αίξ",
        "διασημότητα",
        "γοητευμένος",
        "καταστρατήγηση",
        "συνενοχή",
        "ομολογώ",
        "πονηριά",
        "εξαρτώμενος",
        "ποικίλος",
        "κατακυριεύω",
        "ατελείωτες",
        "επιβάλλω",
        "ερωτικός",
        "διαφυγή",
        "συναισθημα",
        "φλερτάρω",
        "χαλάζι",
        "ηδονισμός",
        "ύψιστος",
        "ταπεινός",
        "αμέσως",
        "ακίνητος",
        "εισόδημα",
        "διήθηση",
        "επιρροή",
        "έντονος",
        "ατελεύτητος",
        "παρέμβαση",
        "δαντέλα",
        "φιλελεύθερος",
        "άρχοντας",
        "μητρικός",
        "μαία",
        "μητέρα",
        "κούπα",
        "κακή φήμη",
        "παντοδυναμία",
        "ξέσπασμα",
        "εξαιρετική",
        "παρέλαση",
        "παράφραση",
        "πετρέλαιο",
        "παρουσίαση",
        "άσωτος",
        "παραθέτω, αναφορά",
        "ουρλιάζω",
        "οπισθοδρομικός",
        "ξανανάβω",
        "λείψανα",
        "συνταξιοδότηση",
        "ανασταίνω",
        "επανάσταση",
        "σκιάχτρο",
        "απομόνωση",
        "αισθησιακός",
        "θέαμα",
        "ΣΠΟΝΔΥΛΙΚΗ ΣΤΗΛΗ",
        "γνήσιος",
        "ζουμερός",
        "δεισιδαιμονία",
        "υπεροχή",
        "περιβάλλω",
        "συνώνυμος",
        "ενθουσιασμός",
        "έφηβοι",
        "θεραπεύω",
        "ανίκητος",
        "αχαλίνωτος",
        "απροσδόκητος",
        "αφάνταστος",
        "λύνω",
        "ανηφορικος ΔΡΟΜΟΣ",
        "ψήφος",
        "βάρος",
        "λαχτάρα",
    ]
)
